/*
JMP Clinical Analytical Process

Name: Standard Safety Reports
Authors:  John Shipway, Geoff Mann, and Russ Wolfinger, SAS Institute Inc.

Description: 
      This process creates various standard safety tabular reports in rtf, pdf, html, or plain text format.
*/

/*
-----------------------------------------------------------
Copyright (C) 2010 SAS Institute, Inc. All rights reserved. 

Notice: 
The above copyright notice and this notice must appear in
any whole or partial copy of this code and any related
documentation. Permission to use, copy, and modify the
source code contained in this file is hereby granted, but
is limited to customers of SAS with a valid license for the
SAS software product with which this file was provided. 
Except as expressly set forth herein, the terms of such
license apply.
-----------------------------------------------------------
*/

*ProcessVariables;

%global StudyName InPath AInPath RInPath Output_RTF Output_PDF Output_HTML Output_Text OutName 
   OutPath ServerOutPath MacroPath StandardSafetyReportsScript
   StandardSafetyReports_Body StandardSafetyReports_Frame StandardSafetyReports_Contents
   DM_Include DM_PATIENT_PROFILES_AGE DM_PATIENT_PROFILES_RACE DM_PATIENT_PROFILES_SEX 
      DM_PATIENT_PROFILES_TREATMENT 
   DS_Include DS_DEATH_AGE_ANALYSIS DS_DEATH_AGE_GROUP DS_DEATH_DAYS_ANALYSIS DS_DEATH_GENDER 
      DS_DEATH_LISTING DS_DEATH_RACE DS_DROPOUT_GROUP_AND_REASON DS_MORTALITY_TREATMENT_GROUP 
   AE_Include AE_BODSYS_SORT_PVAL AE_BODYSYS AE_BY_AGE_GROUP AE_BY_RACE AE_BY_SEX AE_CARDIOVASCULAR 
      AE_DROPOUT_LISTING AE_DRUG_BODYSYS AE_LISTING AE_NO_DEATH AE_PERCENT_BODSYS AE_PERCENT_DRUG_BODSYS 
      AE_RELATIONSHIP_TO_DRUG AE_SEVERITY AE_SUMMARY_REPORT AE_TOTALS
   LB_Include LB_HEPATOTOX_PATIENT_LISTING LB_MEAN_CHANGE_FROM_BASELINE 
      LB_MEAN_CHEM_VALUES_FOR_VISIT VISITN LB_MEAN_VALUES_BASELINE_WORST LB_PATIENT_VISIT_COUNT LB_SIGNIF_CHANGES 
   MH_Include MH_CONDITIONS_SUMMARY
   IncSF PopulationSet SubjectFilter TrtUse TrtVar _slash_
;

*ProcessBody;

%macro StandardSafetyReports;

*initialization and argument checking;
%let ProcessName = StandardSafetyReports; 
%let WhereStmt = ;

%let Domain_List = DM DS AE LB MH;

%let DM_List = DM_PATIENT_PROFILES_AGE DM_PATIENT_PROFILES_RACE DM_PATIENT_PROFILES_SEX 
DM_PATIENT_PROFILES_TREATMENT;

%let DS_List = DS_DEATH_AGE_ANALYSIS DS_DEATH_AGE_GROUP DS_DEATH_DAYS_ANALYSIS DS_DEATH_GENDER 
DS_DEATH_LISTING DS_DEATH_RACE DS_DROPOUT_GROUP_AND_REASON DS_MORTALITY_TREATMENT_GROUP;

%let AE_List = AE_BODSYS_SORT_PVAL AE_BODYSYS AE_BY_AGE_GROUP AE_BY_RACE AE_BY_SEX AE_CARDIOVASCULAR 
AE_DROPOUT_LISTING AE_DRUG_BODYSYS AE_LISTING AE_NO_DEATH AE_PERCENT_BODSYS AE_PERCENT_DRUG_BODSYS 
AE_RELATIONSHIP_TO_DRUG AE_SEVERITY AE_SUMMARY_REPORT AE_TOTALS;

%let LB_List = LB_HEPATOTOX_PATIENT_LISTING LB_MEAN_CHANGE_FROM_BASELINE 
LB_MEAN_CHEM_VALUES_FOR_VISIT LB_MEAN_VALUES_BASELINE_WORST LB_PATIENT_VISIT_COUNT LB_SIGNIF_CHANGES;

%let MH_List = MH_CONDITIONS_SUMMARY;

%let DEATH_TERMS = "DEATH","DEAD","DIED";

%let Output_Text = No;
%let Output_HTML = No;

%include "&MacroPath./UtilityPathMacros.sas" / nosource;
%include "&MacroPath./UtilityMacros.sas" / nosource;
%let IncSF = No;
%include "&MacroPath./CDISCParms.sas";
%include "&MacroPath./ReportMacros.sas";
%if &exiterror %then %goto exit;

*** Error out if SEND data ***;
%if &cdiscmodel=SEND %then %do;
   %put [MS_S_0272];
   %put ERROR: The current study contains SEND data, which does not include the required variables for this analysis.  Please choose a different study.;
   %let exiterror = 1;
   %goto exit;
%end;

%let RInPath = %jg_getPath(/install/clinical/standardreports,,1);

%if &Output_RTF=No and &Output_PDF=No and &Output_HTML=No and &Output_Text=No %then %do;
   %put [MS_S_0010];
   %put ERROR: At least one output format must be selected.;
   %let exiterror = 1;
   %goto exit;
%end;

%if not(&DM_PATIENT_PROFILES_AGE = Yes or &DM_PATIENT_PROFILES_RACE = Yes or &DM_PATIENT_PROFILES_SEX = Yes or 
&DM_PATIENT_PROFILES_TREATMENT = Yes or &DS_DEATH_AGE_ANALYSIS = Yes or &DS_DEATH_AGE_GROUP = Yes or 
&DS_DEATH_DAYS_ANALYSIS = Yes or &DS_DEATH_GENDER = Yes or 
&DS_DEATH_LISTING = Yes or &DS_DEATH_RACE = Yes or &DS_DROPOUT_GROUP_AND_REASON = Yes or &DS_MORTALITY_TREATMENT_GROUP = Yes or 
&AE_BODSYS_SORT_PVAL = Yes or &AE_BODYSYS = Yes or &AE_BY_AGE_GROUP = Yes or &AE_BY_RACE = Yes or &AE_BY_SEX = Yes or 
&AE_CARDIOVASCULAR = Yes or &AE_DROPOUT_LISTING = Yes or &AE_DRUG_BODYSYS = Yes or &AE_LISTING = Yes or &AE_NO_DEATH = Yes or 
&AE_PERCENT_BODSYS = Yes or &AE_PERCENT_DRUG_BODSYS = Yes or &AE_RELATIONSHIP_TO_DRUG = Yes or &AE_SEVERITY = Yes or 
&AE_SUMMARY_REPORT = Yes or &AE_TOTALS = Yes or &LB_HEPATOTOX_PATIENT_LISTING = Yes or &LB_MEAN_CHANGE_FROM_BASELINE = Yes or 
&LB_MEAN_CHEM_VALUES_FOR_VISIT = Yes or &LB_MEAN_VALUES_BASELINE_WORST = Yes or &LB_PATIENT_VISIT_COUNT = Yes or 
&LB_SIGNIF_CHANGES = Yes or &MH_CONDITIONS_SUMMARY = Yes) %then %do;
   %put [MS_S_0344];
   %put ERROR: At least one analysis must be selected.;
   %let exiterror = 1;
   %goto exit;
%end;

%if &sysscp = WIN %then %do;
   %let _slash_ = \;
%end;
%else %do;
   %let _slash_ = /;
%end;
%if %length(&RInPath) %then %CheckEndSlash(RInPath);

%if ^%length(&OutName) %then %do;
   %let OutName = &StudyName;
%end;
%let FullOutName = ;
%PrepOutFile(FullOutName,OutName2,&OutName);
%let OutName = &OutName2;

%ReportTemplate;
ods escapechar='^';
options nobyline nodate missing = "" orientation = landscape;
%if &Output_RTF = Yes %then %do;
   ods rtf file="&FullOutName..rtf" style=styles.tfl_table bodytitle contents notoc_data;*styles.tfl_table;
%end;

%if &Output_PDF = Yes %then %do;
   ods pdf file="&FullOutName..pdf" pdftoc = 2 style = styles.tfl_table contents=yes;
%end;

%if &Output_HTML = Yes %then %do;
   %PrepHTML(
      StandardSafetyReports_Body, 
      StandardSafetyReports_Frame, 
      StandardSafetyReports_Contents, 
      &OutName._body.html, 
      &OutName._frame.html, 
      &OutName._contents.html
   );
   ods html 
      body = "&StandardSafetyReports_Body" (url="&bodyfile")
      frame = "&StandardSafetyReports_Frame"  (url="&framefile")
      contents = "&StandardSafetyReports_Contents" (url="&contentsfile")
   ;
%end;
/*
%put ERROR: &outname;
%put ERROR: &StandardSafetyReports_Body;
%put ERROR: &bodyfile;
%let exiterror=1; %goto exit;
*/
%if &Output_Text = No %then %do;
   ods listing close;
%end;

%if &syserr > 4 %then %goto exit;

*** Prepare ADSL ***;
%PREPADSL;
%if &exiterror %then %goto exit;

%if &Server = Local %then %do;
   %include "&RInPath.MACROS.sas";
%end;
%else %do;
   %include "&RInPath.StandardReports/MACROS.sas";
%end;
%if &exiterror %then %goto exit;
/* %preProcess; */
%initLibname;  
%sortData;
options nofmterr nosymbolgen;

%if &syserr > 4 %then %goto exit;

%put Domain_List = &Domain_List;
%let _d=1;
%do %while(%length(%scan(&Domain_List,&_d)));
   %let _domain = %scan(&Domain_List,&_d);
   %if ^%sysfunc(findw(&domains, &_domain)) and &&&_domain._Include = Yes %then %do;
      %let &_domain._Include = No;
      %put [MS_S_0173];
      %put ERROR: The &_domain data set does not exist for this study.  Reports for this domain are not created.;
   %end;
   %put &_domain &&&_domain._Include;
   %if (&&&_domain._Include = Yes) %then %do;
      %put Creating &_domain Reports...;
      %let _i=1;
      %do %while(%length(%scan(&&&_domain._List,&_i)));
         %let rep = %scan(&&&_domain._List,&_i);
         %put Report &rep: &&&rep;
         %if &&&rep = Yes %then %do;
            %if ^%sysfunc(findw(&domains, DS)) and &_domain = AE and &rep = AE_DROPOUT_LISTING %then %do;
               %put [MS_S_0174];
               %put ERROR: The DS data set does not exist for this study.  The &rep Report for the AE domain cannot be created.;
            %end;
               %else %do;
                  %if &Server = Local %then %do;
                     %include "&RInPath.&rep..sas";
                  %end;
                  %else %do;
                     %include "&RInPath.StandardReports/&rep..sas";
                  %end;                
                  %if &syserr > 4 %then %goto exit;
               %end;
         %end;
         %let _i = %eval(&_i+1);
      %end;
   %end;
   %let _d = %eval(&_d+1);
%end;

%if &Output_RTF = Yes %then %do;
   ods rtf close;
%end;

%if &Output_PDF = Yes %then %do;
   ods pdf close;
%end;

%if &Output_HTML = Yes %then %do;
   ods html close;
%end;

%if &Output_Text = No %then %do;
   ods listing;
%end;

%if &syserr > 4 %then %goto exit;

* create JSL file;
%PrepOutFile(StandardSafetyReportsScript,StandardSafetyReportsScriptName,&StudyName &ProcessName Script.jsl);
%global _mainjslfile_ FullAPName;
%let _mainjslfile_ = &StandardSafetyReportsScript;
%let FullAPName = Standard Safety Reports;
%if &Server^=Local %then %do;
   %let FullOutName = &ClientOutPath.&OutName;
   %let OutPath2 = &ClientOutPath;
%end;
%else %do;
   %let OutPath2 = &OutPath;
%end;
%let OutName2 = StandardSafetyReports__&OutName;
%let FullOutName2 = &ClientOutPath.&OutName2;
%put OutName2 = &OutName2;

%let trSafetyReport = %nrbquote(%LocaleGet(StandardSafetyReports_Text));
%let trOpen = %nrbquote(%LocaleGet(Open_Text));

filename jslfile "&_mainjslfile_";
data _null_;
   file jslfile %if %nrbquote(&SYSENCODING) ne wlatin1 %then encoding="utf-8";;
   put '//!';
      put '//!';
      put "Names Default to Here(1);";
      put "objRefNS = newnamespace();";
      put "jg:currentObjRefNamespaceName = objRefNS << getName;";        
      put "objRefNS:DataList = {};";
      put "objRefNS:TabButtonList = {};";
      put "objRefNS:TabCodeList = {};";
      put "objRefNS:TabAfterCodeList = {};";
      put "objRefNS:TabOpenList = {};";
      put "objRefNS:CreateReportList = {};";  
      put "objRefNS:ShowDataTables = 0;";
      put "objRefNS:ShowCreateReport = 0;";
      put "objRefNS:ShowNotes = 0;";   
      put "objRefNS:fbox=Function({},{default local},";
      put "   Vlistbox(";   
      %let _fCount_ = 0;
      %if &Output_RTF = Yes and ^&exiterror %then %do;
         %let _fCount_ = %eval(&_fCount_+1);
         %let _fList_ = &OutName..rtf;
         put "      objRefNS:Button1=ButtonBox(""&trOpen &trSafetyReport..rtf"",";
         put "          Open(""&ClientOutPath.&OutName..rtf"");";
         put "      ),";
         put "      objRefNS:Button1 << Underline Style(1),";   
      %end;
      %if &Output_PDF = Yes and ^&exiterror %then %do;
         %let _fCount_ = %eval(&_fCount_+1);
         %if &_fCount_ = 1 %then %do;
            %let _fList_ = &OutName..pdf;
         %end;
         %else %do;
            %let _fList_ = &_fList_,&OutName..pdf;
         %end;
         put "      objRefNS:Button2=ButtonBox(""&trOpen &trSafetyReport..pdf"",";
         put "          Open(""&ClientOutPath.&OutName..pdf"");";
         put "      ),";
         put "      objRefNS:Button2 << Underline Style(1),";   
      %end;
      %if &Output_HTML = Yes and ^&exiterror %then %do;
         %let _fCount_ = %eval(&_fCount_+1);
         %if &_fCount_ = 1 %then %do;
            %let _fList_ = "&bodyfile,&framefile,&contentsfile";
         %end;
         %else %do;
            %let _fList_ = &_fList_,&bodyfile,&framefile,&contentsfile;
         %end;
         put "      objRefNS:Button2=ButtonBox(""&trOpen &trSafetyReport..html"",";
         put "          Web(""&ClientOutPath.&framefile"");";
         put "      ),";
         put "      objRefNS:Button2 << Underline Style(1),";   
      %end;
      put "   )";
      put ");";   
      %if &_fCount_ > 1 %then %do;
         %let _fList_ = "&_fList_";
      %end;
      put "InsertInto(objRefNS:DataList,{{""  ""}});";
      put "InsertInto(objRefNS:TabButtonList, Expr(locale:get(""StandardSafetyReports_Text"")));";
      put "InsertInto(objRefNS:TabCodeList,expr(objRefNS:fbox()));";
      put "InsertInto(objRefNS:TabAfterCodeList, "" "");";
      put "InsertInto(objRefNS:TabOpenList,1);";    
   run;
   
   /*
   %let _fCount_ = 0;
   %let _fList_ = ;
   %if &Output_RTF = Yes %then %do;
      %let _fCount_ = %eval(&_fCount_+1);
      %let _fList_ = &OutName..rtf;
      put 'open("'"&FullOutName..rtf"'", JMP window);';
   %end;
   %if &Output_PDF = Yes %then %do;
      %let _fCount_ = %eval(&_fCount_+1);
      %if &_fCount_ = 1 %then %do;
         %let _fList_ = &OutName..pdf;
      %end;
      %else %do;
         %let _fList_ = &_fList_,&OutName..pdf;
      %end;
      put 'open("'"&FullOutName..pdf"'", JMP window);';
   %end;
   %if &Output_Text = Yes %then %do;
      %if ^%symexist(WorkFlowrp) %then %let WorkflowRp = -1;
      %if ^%symexist(_Run_From_WFB_) %then %let _Run_From_WFB_ = 0;
      %if (&WorkFlowrp ne -1) and (^%symexist(CVing) | &_Run_From_WFB_) %then %do;
         put "open(""&ClientOutPath.&OriginalProcessName._&WorkFlowrp..lst"", JMP window);";
      %end;
      %else %do;
         put 'open("'"&FullOutName2..lst"'", JMP window);';
      %end;
   %end;
   %if &Output_HTML = Yes %then %do;
      %let _fCount_ = %eval(&_fCount_+1);
      %if &_fCount_ = 1 %then %do;
         %let _fList_ = "&bodyfile,&framefile,&contentsfile";
      %end;
      %else %do;
         %let _fList_ = &_fList_,&bodyfile,&framefile,&contentsfile;
      %end;
      put 'Web("file://'"&OutPath2.&framefile"'", JMP window);';
   %end;
   %if &_fCount_ > 1 %then %do;
      %let _fList_ = "&_fList_";
   %end;
   put 'throw();';
run;*/

%PackageInsertFile(jsl code from &ProcessName, &OutPath, &StandardSafetyReportsScriptName,&_fList_,text/plain, yes);

/* %postProcess; */

%let OutName = LastRun;

%exit:;

%ExitSDSProcess(&OutPath, &ProcessName, &syserr, &exiterror, &clockrunning);

%mend StandardSafetyReports;

* run the macro;
%StandardSafetyReports;


