
*Adverse event summary program;
*Description:  Read Demographic (1 rec/subject) and AE (1 rec/AE) datasets and generate AE summary table ;
*define variable names;

%let subjid = USUBJID;
%let keySegmentation=RACE;  *this variable is the high level segmentation for the report;
%let advp = AEDECOD;  *AE prefered term;
%let advbs = AEBODSYS; *AE body system;
%let advsev=AESEV; *AE severity;
%let advrel=AEREL; *AE relationship to study drug;
%let treat=&TrtName;  *treatment group;


******Step 1***********;
* Select patient population; 
data pop(keep=&subjid &keySegmentation &treat);
   set DM;
   *population subsetting statements here;
   *if age lt 40;
run;

proc sort data = pop out = pop1(keep =&keySegmentation);
	by &keySegmentation;
run;
proc sort nodupkey data = pop1 out = pop1;
	by &keySegmentation;
run;

data pop1;
	set pop1 end = eof;
	catnum = _n_;
	call symput('cat'||left(_n_), &keySegmentation);
	if eof then call symput('maxcat', left(_n_));
run;


*select only subjects in pop;
proc sort data=pop; by &subjid; run;
data temp;  
   merge pop(in=inpop) teae;
   by &subjid;
   if inpop;   *this does an inner join, its dropping the patients that didn't have AEs;
run;

******Step 2***********;
* Summarize population counts by treatment;
proc summary data=pop nway;
   class &keySegmentation;
   output out=nsubj(drop=_type_ rename=(_freq_=nsubj));
run;

******Step 3***********;
*summarize to 1 rec/sub/unique AE(optionally severity/ relationship);
proc summary data=temp;
   class &advbs &advp &subjid &keySegmentation; * &advsev &advrel;
   output out=uniqueae(drop=_freq_ rename=(_type_=level));
   *types &subjid*&keySegmentation &subjid*&keySegmentation*&advbs &subjid*&keySegmentation*&advbs*&advp;
   types &subjid*&keySegmentation &subjid*&keySegmentation*&advp;
run;

******Step 4***********;
*summarize to overall, body system, preferred term, including empty cells;
proc freq data=uniqueae noprint;
   by &advp notsorted;
   table &advp*&keySegmentation/ out=count missing sparse;
run;
proc sort data=count;
   by &keySegmentation &advp;
run;

******Step 5***********;
* add population counts and generate complements(no ae counts) for PROC Freq statistics;
data aefreq;
   merge count nsubj;
   by &keySegmentation;
   *add summary level labels; 
   if &advp eq ' ' then &advp=' Total';
   drop level _type_ nsubj;
   ae="yes";
   output;
   ae="no";
   count=nsubj-count;
   output;
run;

proc sort;
   by &advp;
run;

******Step 6***********;
* compute p values and subset out ae='yes' records;
proc freq noprint order=data;
   by   &advp notsorted;
   table ae*&keySegmentation/out=aecount(where=(ae='yes')drop=percent pct_row) 
      outpct missing sparse;
   exact fisher / n=10000 maxtime=10;
   weight count;
   output fisher  out=aestat;
run;

* check if there is any obervations in aestat. If no obs, it will not run the following part;
%NObsVars(aestat);
%macro TAB;
   %if &nobs >0 %then %do;
      *merge pvalue into counts;
    data aefinal;
         merge aecount aestat;
         by &advp;
		 value = catx(" ",count,cats("(",round(PCT_COL,1),")"));
    run;
	proc sort data=pop1; by &keySegmentation; run;
	proc sort data=aefinal; by &keySegmentation; run;
	data aefinal;
	  		merge aefinal pop1;
			by &keySegmentation; 
	run;
	  
	proc sort data=aefinal; by &advp; run;
	proc transpose data=aefinal out=stats;
	  	by &ADVP;
		id catnum;
		var value;
	run;
	*** Fill in 0 cells;
	data stats;
		   set stats;
		   %do i = 1 %to &maxcat;
		      if _&i = "" then  _&i = "0 (0)";
		   %end;
		   if &ADVP ^="";
	run;
	******Step 7***********;
      * display table;
	proc format;
         picture pct low-high='09)'( prefix='(');
	run;

      %let domain = Adverse Events;
      %let title = Incidence of Treatment-Emergent Adverse Events by Race;

/*      PROC REPORT DATA=WORK.aefinal LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title";*/
/*         *break before &advbs/skip;*/
/*         *COLUMN  &advbs &ADVP  &keySegmentation,( COUNT PCT_COL) xp2_fish;*/
/*         COLUMN  &ADVP  &keySegmentation,( COUNT PCT_COL);*/
/**/
/*         *DEFINE  &advbs / group FORMAT= $7. WIDTH=7     SPACING=2   LEFT "Body System" order=data;*/
/*         DEFINE  &ADVP / group FORMAT= $&aedecodlen.. WIDTH=21    SPACING=2   LEFT "Reported Term for AE" order=data;*/
/*         DEFINE  &keySegmentation / across FORMAT= $&racelen.. WIDTH=10    SPACING=2 LEFT "Race" ;*/
/*         DEFINE  COUNT / SUM FORMAT= BEST9. WIDTH=9     SPACING=2   RIGHT "N" ;*/
/*         DEFINE  PCT_COL / SUM FORMAT= pct4. WIDTH=9     SPACING=2  left "(%)";*/
/*         *Define xp2_fish/min format=5.4  width=9 "Fishers Exact P-value";*/
/**/
/*         title "&title";*/
/*         title2 "ICHE3 Table 14.3.1.8";*/
/*         ods proclabel = "&domain";       */ 
/*      RUN;*/

%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;

	PROC REPORT DATA=WORK.stats LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";

         COLUMN  &ADVP  ("^S={borderbottomcolor=black borderbottomwidth=2} Race" %do i = 1 %to &maxcat; _&i %end;);

         DEFINE  &ADVP / id group FORMAT= $&aedecodlen..   WIDTH=21    SPACING=2   LEFT "Reported Term for AE" order=data style(header)={just=l};
         %do i = 1 %to &maxcat; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&cat&i" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&cat&i" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		   %end; 

         title "&title";
         title2 "ICHE3 Table 14.3.1.10";
         ods proclabel = "&domain";       
	RUN;
	*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
   %end;
%mend TAB;
%TAB;

proc datasets nolist;
   delete temp aecount aestat pop1;
quit;
%postProcess;

