/**********************************************
* Program: Adverse Event Dropout Listing
* Author:  John Shipway, SAS Institute
* Date:  December 10, 2007
* Description:                
* Todo: 
*        Do we need to incorporate dose (EX)?
*       Which time do we use (DS or AE) are they the same? 
*       We could do some slicing and dicing on this table...
***********************************************/

%let subjid = USUBJID;
%let treat=&TrtName;  *treatment group;
%let advp = AEDECOD;  *AE prefered term;
%let advbs = AEBODSYS; *AE body system;
%let advsev=AESEV; *AE severity;
%let advrel=AEREL; *AE relationship to study drug;
%let death=AESDTH; *AE death flag variable;

%let COMPLETION_TERM = "PROTOCOL COMPLETED";
%let DEATH_TERM = "DEATH";
%LET ADVERSE_EVENT_TERM = "ADVERSE EVENT";

/* the start data variable: RFSTDTC or TRTSDT?*/

* Select patient population; 
data pop(keep=&subjid &treat age sex siteid);
   set &in_adsl;
run;
proc sort data=pop; by &subjid; run;
* get dropouts due to AEs;
/*data drop;*/
/*   set ds;*/
/*   if dsdecod ne &DEATH_TERM and dsdecod eq &ADVERSE_EVENT_TERM;*/
/*   dsdecod ne &COMPLETION_TERM and */
/*   if index(epoch,"TREATMENT")>0;*/
/*   if epoch ^="";*/
/*run;*/

proc sql;
	create table drop as
	select * from ds where dsdecod ^= &DEATH_TERM and index(dsdecod,&ADVERSE_EVENT_TERM)>0 and &subjid in
		(select usubjid from dm where rfstdtc^="");
quit;

%NObsVars(drop);

%macro DROP;
   %if &nobs %then %do;
      *merge pop with dropout due to AEs;
      data popdrop;
         merge drop(in=indrop) pop;
         by &subjid;
         if indrop;
      run;

      *load AEs;
/*      data ae;*/
/*         set ae;*/
/*      run;*/

      *merge popdrop with ae fields;
      proc sort data=ae; by &subjid; run;
      proc sort data=popdrop; by &subjid; run;
      data popdropae;
         merge popdrop(in=inpop) ae;
         by &subjid;
         if inpop;
         /* if missing(AESTDY) then do;
            %calcStudyDay(AESTDTC);
         end; */
		 demo = cats("Patient=",USUBJID, ", Trial=",STUDYID,", Center=", siteid,", Age(yrs)=", AGE,", Sex=", SEX);
      run;

      %let domain = Adverse Events;
      %let title = Adverse Event Dropout Listing;

/*      PROC REPORT DATA=popdropae LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title";*/
/*         COLUMN STUDYID siteid USUBJID AGE SEX &treat STDY AEBODSYS AEDECOD AETERM AESER AEOUT;*/
/*         DEFINE  STUDYID /id FORMAT= $&studlen.. WIDTH=6     SPACING=2   LEFT "Trial";*/
/*         DEFINE  siteid / id FORMAT= $&sitelen.. WIDTH=6     SPACING=2   LEFT "Center";*/
/*         DEFINE  USUBJID / id FORMAT= $&sublen.. WIDTH=6     SPACING=2   LEFT "Patient" order=data;*/
/*         DEFINE  AGE / FORMAT= 5. WIDTH=4     SPACING=2   LEFT "Age (yrs)" order=data;*/
/*         DEFINE  SEX / FORMAT= $3. WIDTH=3     SPACING=2   LEFT "Sex" order=data;*/
/*         DEFINE  &treat / FORMAT= $&armlen.. WIDTH=6     SPACING=2   LEFT "&TrtLabel" order=data;*/
/*         DEFINE  STDY / FORMAT= 5. WIDTH=4     SPACING=2   LEFT "Time (days)" order=data;*/
/*         DEFINE  AEBODSYS / FORMAT= $&aebodsyslen.. WIDTH=6     SPACING=2   LEFT "Body System" order=data;*/
/*         DEFINE  AEDECOD / FORMAT= $&aedecodlen.. WIDTH=6     SPACING=2   LEFT "Preferred Term" order=data;*/
/*         DEFINE  AETERM / FORMAT= $&aetermlen.. WIDTH=6     SPACING=2   LEFT "Adverse Event" order=data;*/
/*         DEFINE  AESER / FORMAT= $1. WIDTH=4 SPACING=2 LEFT "Serious" order=data;*/
/*         DEFINE  AEOUT / FORMAT= $&aeoutlen.. WIDTH=6     SPACING=2   LEFT "Outcome" order=data;*/
/**/
/*         TITLE "&title";*/
/*         TITLE2 "Table 7.1.3.2.1 of the GRP"; */
/*         ods proclabel = "&domain";       */
/*      RUN;*/
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	PROC REPORT DATA=popdropae LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";

		 COLUMN &treat STDY AEBODSYS AEDECOD AESER AEOUT demo;
	/*         DEFINE  STUDYID /id FORMAT= $&studlen.. WIDTH=6     SPACING=2   LEFT "Trial";*/
	/*         DEFINE  siteid / id FORMAT= $&sitelen.. WIDTH=6     SPACING=2   LEFT "Center";*/
/*		 DEFINE  USUBJID / id FORMAT= $&sublen.. style(column)=[cellwidth=5%]     SPACING=2   LEFT "Patient" order=data;*/
	/*         DEFINE  AGE / FORMAT= 5. WIDTH=4     SPACING=2   LEFT "Age (yrs)" order=data;*/
	/*         DEFINE  SEX / FORMAT= $3. WIDTH=3     SPACING=2   LEFT "Sex" order=data;*/
		 DEFINE  &treat / FORMAT= $&armlen.. style(column)=[cellwidth=7%]    SPACING=2   LEFT "&TrtLabel" order=data style(header)={just=l};
		 DEFINE  STDY / FORMAT= 5. style(column)=[cellwidth=3%]    SPACING=2   LEFT "Time (days)" order=data style(header)={just=l};
		 DEFINE  AEBODSYS / FORMAT= $&aebodsyslen.. style(column)=[cellwidth=12%]  SPACING=2   LEFT "Body System" order=data style(header)={just=l};
		 DEFINE  AEDECOD / FORMAT= $&aedecodlen.. style(column)=[cellwidth=9%]  SPACING=2   LEFT "Preferred Term" order=data style(header)={just=l};
	/*         DEFINE  AETERM / FORMAT= $&aetermlen.. style(column)=[cellwidth=9%]     SPACING=2   LEFT "Adverse Event" order=data;*/
		 DEFINE  AESER / FORMAT= $1. style(column)=[cellwidth=3%] SPACING=2 LEFT "Serious" order=data style(header)={just=l};
		 DEFINE  AEOUT / FORMAT= $&aeoutlen.. style(column)=[cellwidth=5%]  SPACING=2   LEFT "Outcome" order=data style(header)={just=l};
			 define  demo / group noprint;
				compute before demo / style=[just=l fontweight=bold];
					line demo $100.;
				endcomp;
		 TITLE "&title";
		 TITLE2 "Table 7.1.3.2.1 of the GRP"; 
		 ods proclabel = "&domain";       
      	RUN;
   %end;
   %else %do;
      data aa;
        length note $ 50;
        note = "No Drop Outs Present";
      run;
   
      %let domain = Adverse Events;
      %let title = Adverse Event Dropout Listing;
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	PROC REPORT DATA=aa LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";
   
         COLUMN  note;
   
         DEFINE  note / group FORMAT= $21. WIDTH=21    SPACING=2   LEFT "Note";
         title "&title";
         TITLE2 "Table 7.1.3.2.1 of the GRP"; 
         ods proclabel = "&domain";       
      RUN;
      *ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
      
      proc datasets nolist;
         delete aa;
      quit;
   %end;
   
%mend DROP;
%DROP
%postProcess;







