/**********************************************
* Adverse Event Listing
* Author:  John Shipway, SAS Institute
* Date:  December 10, 2007
* Description:                
* Todo: 
*     Do we need to incorporate dose (EX)?
*       Which time do we use (DS or AE) are they the same? 
***********************************************/

options nofmterr nosymbolgen;

%let DS_ADVERSE_EVENT_TERM = "ADVERSE EVENT";
%let treat= &TrtName;  *treatment group;

%macro AELISTING;
*merge ae with demography;

data aedm;
   merge teae(in=inae) &in_adsl end = eof;
   by &subjid;
   if inae;
   *if eof then call symput("vartype", vtype(&treat));   
run;

data _null_;
   set aedm(obs = 1);
   call symput("vartype", vtype(&treat));    
run;

*merge ae with ds to see if ae led to widthrawl for W/D field;
*if dsdecod in the ds table = ADVERSE EVENT, then that means the AE led to a dropout...;
*Make conditional for when DS does not exist to get most of report;

%let DSCAT = ;
%if %sysfunc(findw(&domains, DS)) %then %do;
   %if %sysfunc(findw(%upcase(&DSVARS), DSCAT)) %then %let DSCAT = DSCAT;
%end;
%let DSDECOD = ;
%if %sysfunc(findw(&domains, DS)) %then %do;
   %if %sysfunc(findw(%upcase(&DSVARS), DSDECOD)) %then %let DSDECOD = DSDECOD;
%end;

%let trDispositionEvent = %nrbquote(%LocaleGet(DispositionEvent_Text));

%if %length(&DSCAT) and %length(&DSDECOD) %then %do;   
   *** to keep a single disposition record ***;
   data subds(drop = stdy);
      set ds(where = (upcase(DSCAT) = "%upcase(&trDispositionEvent)"));
      if last.usubjid;      
   run;
   proc sort data=subds; by &subjid; run;
   proc sort data=aedm; by &subjid; run;
   data aedmds;
      merge aedm(in=inaedm) subds;
      by &subjid;
      if inaedm;
      if dsdecod eq "ADVERSE EVENT" then Withdrew ="Y";
      else Withdrew="N";
	  demo = cats("Patient=",&SUBJID , ", Trial=",STUDYID,", Center=", siteid,", Age(yrs)=", AGE,", Sex=", SEX);
   run;
   
   proc datasets nolist;
      delete subds;
   quit;   
%end;
%else %do;
   data aedmds;
      set aedm;
	  demo = cats("Patient=",USUBJID, ", Trial=",STUDYID,", Center=", siteid,", Age(yrs)=", AGE,", Sex=", SEX);
   run;
%end;   

%let domain = Adverse Events;
%let title = Treatment Emergent Adverse Event Listing;

%macro TAB;
/*PROC REPORT DATA=aedmds LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title";*/
/*   COLUMN STUDYID SITEID USUBJID AGE SEX &treat STDY AEBODSYS AEDECOD AETERM AESER AEOUT %if %sysfunc(findw(&domains, DS)) %then %do; WITHDREW %end; ;*/
/*   DEFINE  STUDYID /ID  FORMAT= $&studlen.. WIDTH=6     SPACING=2   LEFT "Trial";*/
/*   DEFINE  SITEID /ID FORMAT= $&sitelen.. WIDTH=6     SPACING=2   LEFT "Center";*/
/*   DEFINE  USUBJID /ID FORMAT= $&sublen.. WIDTH=6     SPACING=2   LEFT "Patient" order=data;*/
/*   DEFINE  AGE / FORMAT= 5. WIDTH=4     SPACING=2   LEFT "Age (yrs)" order=data;*/
/*   DEFINE  SEX / FORMAT= $3. WIDTH=3     SPACING=2   LEFT "Sex" order=data;*/
/*   DEFINE  &treat / %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=6     SPACING=2   LEFT "&TrtLabel" order=data;*/
/*   DEFINE  STDY / FORMAT= 5. WIDTH=4     SPACING=2   LEFT "Time (days)" order=data;*/
/*   DEFINE  AEBODSYS / FORMAT= $&aebodsyslen.. WIDTH=6     SPACING=2   LEFT "Body System" order=data;*/
/*   DEFINE  AEDECOD / FORMAT= $&aedecodlen.. WIDTH=6     SPACING=2   LEFT "Preferred Term" order=data;*/
/*   DEFINE  AETERM / FORMAT= $&aetermlen.. WIDTH=6     SPACING=2   LEFT "Adverse Event" order=data;*/
/*   DEFINE  AESER / FORMAT= $1. WIDTH=4 SPACING=2 LEFT "Serious" order=data;*/
/*   DEFINE  AEOUT / FORMAT= $&aeoutlen.. WIDTH=6     SPACING=2   LEFT "Outcome" order=data;*/
/*   %if %sysfunc(findw(&domains, DS)) %then %do;*/
/*      DEFINE  WITHDREW / FORMAT= $1. WIDTH=5 SPACING=2 LEFT "Withdrew" order=data;*/
/*   %end;*/
/*   TITLE "&title";*/
/*   TITLE2 "Table 7.1.5.2.1 of the GRP"; */
/*   ods proclabel = "&domain";       */
/*RUN;*/

%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
PROC REPORT DATA=aedmds LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";
   COLUMN &treat STDY AEBODSYS AEDECOD AESER AEOUT %if %sysfunc(findw(&domains, DS)) %then %do; WITHDREW %end; demo;
/*   DEFINE  STUDYID /ID  FORMAT= $&studlen.. WIDTH=6     SPACING=2   LEFT "Trial";*/
/*   DEFINE  SITEID /ID FORMAT= $&sitelen.. WIDTH=6     SPACING=2   LEFT "Center";*/
/*   DEFINE  USUBJID /ID FORMAT= $&sublen.. style(column)=[cellwidth=5%]  SPACING=2   LEFT "Patient" order=data;*/
/*   DEFINE  AGE / FORMAT= 5. WIDTH=4     SPACING=2   LEFT "Age (yrs)" order=data;*/
/*   DEFINE  SEX / FORMAT= $3. WIDTH=3     SPACING=2   LEFT "Sex" order=data;*/
   DEFINE  &treat / %if &vartype = C %then %do; FORMAT= $&armlen.. %end; style(column)=[cellwidth=7%]    SPACING=2   LEFT "&TrtLabel" order=data style(header)={just=l};
   DEFINE  STDY / FORMAT= 5. style(column)=[cellwidth=3%] SPACING=2   LEFT "Time (days)" order=data style(header)={just=l};
   DEFINE  AEBODSYS / FORMAT= $&aebodsyslen.. style(column)=[cellwidth=12%]  SPACING=2   LEFT "Body System" order=data style(header)={just=l};
   DEFINE  AEDECOD / FORMAT= $&aedecodlen.. style(column)=[cellwidth=9%] SPACING=2   LEFT "Preferred Term" order=data style(header)={just=l};
/*   DEFINE  AETERM / FORMAT= $&aetermlen.. style(column)=[cellwidth=9%]   SPACING=2   LEFT "Adverse Event" order=data;*/
   DEFINE  AESER / FORMAT= $1. style(column)=[cellwidth=3%] SPACING=2 LEFT "Serious" order=data style(header)={just=l};
   DEFINE  AEOUT / FORMAT= $&aeoutlen.. style(column)=[cellwidth=5%]  SPACING=2   LEFT "Outcome" order=data style(header)={just=l};
   %if %sysfunc(findw(&domains, DS)) %then %do;
      DEFINE  WITHDREW / FORMAT= $1. style(column)=[cellwidth=3%] SPACING=2 LEFT "Withdrew" order=data style(header)={just=l};
   %end;
   define  demo / group noprint;
			compute before demo / style=[just=l fontweight=bold];
				line demo $100.;
			endcomp;
   TITLE "&title";
   TITLE2 "Table 7.1.5.2.1 of the GRP"; 
   ods proclabel = "&domain";       
RUN;
*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%mend TAB;
%TAB;

%postProcess;
%mend AELISTING;

%AELISTING;
