/**********************************************
* Program: Adverse event not resulting in death summary program
* Author:  John Shipway, SAS Institute
* Date:  December 10, 2007
* Description:  Read Demographic (1 rec/subject) and AE (1 rec/AE) datasets and generate AE summary table ;
*               define variable names;
* Todo: 
*     in report, note, AEENRF (2nd to last) are just placeholders until we can get the center
*       dose, and adverse event description data. 
***********************************************/


%let subjid = USUBJID;
%let treat=&TrtName;  *treatment group;
%let advp = AEDECOD;  *AE prefered term;
%let advbs = AEBODSYS; *AE body system;
%let advsev=AESEV; *AE severity;
%let advrel=AEREL; *AE relationship to study drug;
%let death=AESDTH; *AE death flag variable;
%let TERM_ADVERSE_EVENT="ADVERSE EVENT";

%macro AENODEATH;

******Step 1***********;
* Select patient population; 
data pop(keep=&subjid &treat age sex siteid);
   set &in_adsl end = eof;
   *population subsetting statements here;
   *if age lt 40;
   if eof then call symput("vartype", vtype(&treat));    
run;

*select only subjects in pop that had adverse events;
*check if ae resulted in death (AESDTH);

%let DSCAT = ;
%if %sysfunc(findw(&domains, DS)) %then %do;
   %if %sysfunc(findw(%upcase(&DSVARS), DSCAT)) %then %let DSCAT = DSCAT;
%end;
%let DSDECOD = ;
%if %sysfunc(findw(&domains, DS)) %then %do;
   %if %sysfunc(findw(%upcase(&DSVARS), DSDECOD)) %then %let DSDECOD = DSDECOD;
%end;

proc sort data=pop; by &subjid; run;
data temp;  
   merge pop(in=inpop) ae;
   by &subjid; 
   if inpop and AESER = "Y";
run;

*merge ae with ds to see if ae led to widthrawl for W/D field;
*if dsdecod in the ds table = ADVERSE EVENT, then that means the AE led to a dropout...;
*Make conditional for when DS does not exist to get most of report;

%let trDispositionEvent = %nrbquote(%LocaleGet(DispositionEvent_Text));
%if %length(&DSCAT) and %length(&DSDECOD) %then %do;
   *** to keep a single disposition record ***;
   data subds(drop = stdy);
      set ds(where = (upcase(DSCAT) = "%upcase(&trDispositionEvent)"));
      if last.usubjid;
   run;
   proc sort data=subds; by usubjid; run;
   proc sort data=temp; by usubjid; run;

   data aeds;
      merge temp(in=inae) subds;
      by usubjid;
      if inae;
      if upcase(dsdecod) eq &TERM_ADVERSE_EVENT then Withdrew ="Yes";
      else Withdrew="No";
	  demo = cats(" Trial=",STUDYID,", Center=", siteid,", Age(yrs)=", AGE,", Sex=", SEX);
   run;
   
   proc datasets nolist;
      delete subds;
   quit;   
%end;
%else %do;
   data aeds;
      set temp;
	  demo = cats(" Trial=",STUDYID,", Center=", siteid,", Age(yrs)=", AGE,", Sex=", SEX);
   run;
%end;

%macro TAB;
%let domain = Adverse Events;
%let title = Serious Adverse Event Listing;

/*PROC REPORT DATA=WORK.aeds LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title";*/
/*   *dose column prob. needs to be modified to use EX domain;*/
/*   COLUMN STUDYID siteid USUBJID AGE SEX &treat STDY AEBODSYS AEDECOD AETERM %if %sysfunc(findw(&domains, DS)) %then %do; WITHDREW %end; ;*/
/*   DEFINE  STUDYID /ID FORMAT= $&studlen.. WIDTH=6     SPACING=2   LEFT "Trial";*/
/*   DEFINE  siteid /ID FORMAT= $&sitelen.. WIDTH=6     SPACING=2   LEFT "Center";*/
/*   DEFINE  SUBJID /ID FORMAT= $&sublen.. WIDTH=6     SPACING=2   LEFT "Patient" order=data;*/
/*   DEFINE  AGE / FORMAT= 5. WIDTH=4     SPACING=2   LEFT "Age (yrs)" order=data;*/
/*   DEFINE  SEX / FORMAT= $3. WIDTH=3     SPACING=2   LEFT "Sex" order=data;*/
/*   DEFINE  &treat / %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=6     SPACING=2   LEFT "&TrtLabel" order=data;*/
/*   DEFINE  STDY / FORMAT= 6. WIDTH=4     SPACING=2   LEFT "Time (days)" order=data;*/
/*   DEFINE  AEBODSYS / FORMAT= $&aebodsyslen.. WIDTH=6     SPACING=2   LEFT "Body System" order=data;*/
/*   DEFINE  AEDECOD / FORMAT= $&aedecodlen.. WIDTH=6     SPACING=2   LEFT "Preferred Term" order=data;*/
/*   DEFINE  AETERM / FORMAT= $&aetermlen.. WIDTH=6     SPACING=2   LEFT "Adverse Event" order=data;*/
/*   %if %sysfunc(findw(&domains, DS)) %then %do;*/
/*      DEFINE  WITHDREW / FORMAT= $3. WIDTH=4     SPACING=2   LEFT "W/D" order=data;*/
/*   %end;*/
/*   TITLE "&title";*/
/*   *TITLE 'Listing of Subjects with Serious Adverse Events Other Than Death';*/
/*   TITLE2 'GRP Table 7.1.2.1'; */
/*   ods proclabel = "&domain";       */
/*RUN;*/
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;

PROC REPORT DATA=WORK.aeds LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";
   *dose column prob. needs to be modified to use EX domain;
   COLUMN USUBJID &treat STDY AEBODSYS AEDECOD %if %sysfunc(findw(&domains, DS)) %then %do; WITHDREW %end; demo;
/*   DEFINE  STUDYID /ID FORMAT= $&studlen.. WIDTH=6     SPACING=2   LEFT "Trial";*/
/*   DEFINE  siteid /ID FORMAT= $&sitelen.. WIDTH=6     SPACING=2   LEFT "Center";*/
   DEFINE  USUBJID /ID FORMAT= $&sublen.. style(column)=[cellwidth=5%]     SPACING=2   LEFT "Patient" order=data style(header)={just=l};
/*   DEFINE  AGE / FORMAT= 5. WIDTH=4     SPACING=2   LEFT "Age (yrs)" order=data;*/
/*   DEFINE  SEX / FORMAT= $3. WIDTH=3     SPACING=2   LEFT "Sex" order=data;*/
   DEFINE  &treat / %if &vartype = C %then %do; FORMAT= $&armlen.. %end; style(column)=[cellwidth=7%]  SPACING=2   LEFT "&TrtLabel" order=data style(header)={just=l};
   DEFINE  STDY / FORMAT= 6. style(column)=[cellwidth=3%]  SPACING=2   LEFT "Time (days)" order=data style(header)={just=l};
   DEFINE  AEBODSYS / FORMAT= $&aebodsyslen.. style(column)=[cellwidth=12%]  SPACING=2   LEFT "Body System" order=data style(header)={just=l};
   DEFINE  AEDECOD / FORMAT= $&aedecodlen.. style(column)=[cellwidth=9%]  SPACING=2   LEFT "Preferred Term" order=data style(header)={just=l};
/*   DEFINE  AETERM / FORMAT= $&aetermlen.. style(column)=[cellwidth=9%]  SPACING=2   LEFT "Adverse Event" order=data;*/
   %if %sysfunc(findw(&domains, DS)) %then %do;
      DEFINE  WITHDREW / FORMAT= $3. style(column)=[cellwidth=3%]  SPACING=2   LEFT "W/D" order=data style(header)={just=l};
   %end;
   define  demo / group noprint;
			compute before demo / style=[just=l fontweight=bold];
				line demo $100.;
			endcomp;
   TITLE "&title";
   *TITLE 'Listing of Subjects with Serious Adverse Events Other Than Death';
   TITLE2 'GRP Table 7.1.2.1'; 
   ods proclabel = "&domain";       
RUN;
*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";

%mend TAB;
%TAB;

proc datasets nolist;
   delete temp;
quit;

%postProcess;
%mend AENODEATH;

%AENODEATH;
