
*Adverse event summary program;
*Author:  Dave Christiansen, Christiansen Consulting;
*Date:  Nov 12, 2004;
*Description:  Read Demographic (1 rec/subject) and AE (1 rec/AE) datasets and generate AE summary table ;
*define variable names;

%let subjid = USUBJID;
%let treat=&TrtName;  *treatment group;
%let advp = AEDECOD;  *AE prefered term;
%let advbs = AEBODSYS; *AE body system;

/**
  John, these two are only useful if you want to swap them out for advbs (body system).
  In other words, you might want your table organized by severity rather than body system.
**/
%let advsev=AESEV; *AE severity;
%let advrel=AEREL; *AE relationship to study drug;


******Step 1***********;
* Select patient population; 
data pop(keep=&subjid &treat);
   set &in_adsl end = eof;
   *population subsetting statements here;
   if eof then call symput("vartype", vtype(&treat));    
run;

*select only subjects in pop;
proc sort data=pop; by &subjid; run;
data temp;  
   merge pop(in=inpop) ae;
   by &subjid;
   if inpop;   *this does an inner join, its dropping the patients that didn't have AEs;
run;

proc sort data = TEMP out = POP1(keep = &trtname);
	by &trtname;
run;
proc sort nodupkey data = POP1 out = POP1;
	by &trtname;
run;
%SortRowsByValueOrdering(POP1, &treat);
data POP1;
	set POP1 end = eof;
	trtnum = _n_;
	call symput('TRT'||left(_n_), &trtname);
	if eof then call symput('maxtrt', left(_n_));
run;

******Step 2***********;
* Summarize population counts by treatment;
proc summary data=pop nway;
   class &treat;
   output out=nsubj(drop=_type_ rename=(_freq_=nsubj));
run;

******Step 3***********;
*summarize to 1 rec/sub/unique AE(optionally severity/ relationship);
proc summary data=temp;
   class &advbs &advp &subjid &treat; * &advsev &advrel;
   output out=uniqueae(drop=_freq_ rename=(_type_=level));
   types &subjid*&treat &subjid*&treat*&advbs &subjid*&treat*&advbs*&advp;
run;

******Step 4***********;
*summarize to overall, body system, preferred term, including empty cells;
proc freq data=uniqueae noprint;
   by &advbs notsorted;
   table &advp*&treat/ out=count missing sparse;
run;
proc sort data=count;
   by &treat &advbs &advp;
run;

******Step 5***********;
* add population counts and generate complements(no ae counts) for PROC Freq statistics;
data aefreq;
   merge count nsubj;
   by &treat;
   *add summary level labels;
   if &advbs eq ' ' then &advp=" Any Adverse Events";
   if &advp eq ' ' then &advp=' Total';
   drop level _type_ nsubj;
   ae="yes";
   output;
   ae="no";
   count=nsubj-count;
   output;
run;

proc sort;
   by &advbs &advp;
run;

******Step 6***********;
* compute p values and subset out ae='yes' records;
proc freq noprint order=data;
   by   &advbs &advp notsorted;
   table ae*&treat/out=aecount(where=(ae='yes')drop=percent pct_row) 
      outpct missing sparse;
   exact fisher / n=10000 maxtime=10;
   weight count;
   output fisher  out=aestat;
run;

* check if there is any obervations in aestat. If no obs, it will not run the following part;
%NObsVars(aestat);
%macro TAB;
   %if &nobs >0 %then %do;
      *merge pvalue into counts;
/*      data aefinal;*/
/*         merge aecount aestat;*/
/*         by &advbs &advp;*/
/*      run;*/
   
      PROC SORT DATA=AECOUNT; BY &treat; run;
		 proc sort data=pop1; by &treat; run;
		 data aecount;
		 	merge aecount pop1;
			by &treat;
		 run;
		 proc sort data=aecount; by &advbs &advp; run;
         data aefinal;
            merge aecount aestat;
            BY &advbs &advp;
			if &advp ^="";
			value = catx(" ",count,cats("(",round(pct_col,1),")"));
         run;

		 proc sort data = aefinal;
		   by &advbs &advp xp2_fish;
		 run;
		** PROC REPORT format dataset;
		proc transpose data =aefinal out = stats;
		   by &advbs &advp xp2_fish;
		   id trtnum;
		   var value;
		run;
		*** Fill in 0 cells;
		data stats;
		   set stats;
		   %do i = 1 %to &maxtrt;
		      if _&i = "" then  _&i = "0 (0)";
		   %end;
		run;

      ******Step 7***********;
      * display table;
      proc format;
         picture pct low-high='09)'( prefix='(');
      run;

      %let domain = Adverse Events;
      %let title = Adverse Event Summary Report;

/*      PROC REPORT DATA=WORK.aefinal LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title";*/
/*         break before &advbs/skip;*/
/*         COLUMN  &advbs &ADVP  &treat,( COUNT PCT_COL) xp2_fish;*/
/**/
/*         DEFINE  &advbs / group FORMAT= $&aebodsyslen.. WIDTH=7     SPACING=2   LEFT "Body System" order=data;*/
/*         DEFINE  &ADVP / group FORMAT= $&aedecodlen.. WIDTH=21    SPACING=2   LEFT "Reported Term for AE" order=data;*/
/*         DEFINE  &TREAT / across %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=10    SPACING=2   LEFT*/
/*         "&TrtLabel" ;*/
/*         DEFINE  COUNT / SUM FORMAT= BEST9. WIDTH=9     SPACING=2   RIGHT "N" ;*/
/*         DEFINE  PCT_COL / SUM FORMAT= pct4. WIDTH=9     SPACING=2  left "(%)";*/
/*         Define xp2_fish/min format=5.4  width=9 "Fishers Exact P-value";*/
/**/
/*         title "&title";*/
/*         ods proclabel = "&domain";       */
/*      RUN;*/
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	PROC REPORT DATA=WORK.STATS LS=97  PS=54  SPLIT="|" CENTER nowindows missing contents="&Title.";
         break before &advbs/skip;
         column &advBS &ADVP ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;)  xp2_fish;
         DEFINE  &advbs /id group FORMAT= $&aebodsyslen.. style(column)=[cellwidth=9%]     SPACING=2   LEFT "Body System" order=data style(header)={just=l};
         DEFINE  &ADVP /id group FORMAT= $&aedecodlen.. style(column)=[cellwidth=15%]    SPACING=2   LEFT "Reported Term for AE" order=data style(header)={just=l};
         %do i = 1 %to &maxtrt; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		 %end; 
		 %if %sysfunc(mod(&maxtrt,5))=0 %then %do;
		   		define xp2_fish / page min format=5.4  width=9 "Fishers Exact P-value";
		 %end;
   		 %else %do;
		   		define xp2_fish / min format=5.4  width=9 "Fishers Exact P-value";
		 %end;

         title "&title";
         ods proclabel = "&domain";       
      RUN;
   %end;
%mend TAB;
%TAB;

proc datasets nolist;
   delete temp aecount aestat POP1;
quit;
