
*Adverse event summary program;
*Description:  Read Demographic (1 rec/subject) and AE (1 rec/AE) datasets and generate AE summary table ;
*define variable names;

*for this one, don't worry about segmenting by treatment (ARM, placebo or drug);


%let subjid = USUBJID;
%let treat=&TrtName;  *treatment group;
%let advp = AEDECOD;  *AE prefered term;
%let advbs = AEBODSYS; *AE body system;

/**
  John, these two are only useful if you want to swap them out for advbs (body system).
  In other words, you might want your table organized by severity rather than body system.
**/
%let advsev=AESEV; *AE severity;
%let advrel=AEREL; *AE relationship to study drug;


******Step 1***********;
* Select patient population; 
data pop(keep=&subjid &treat);
   set &in_adsl;
   *population subsetting statements here;
   *if age lt 40;
run;

*select only subjects in pop with events;
proc sort data=pop; by &subjid; run;
data temp(where = (aeterm ne ""));  
   merge pop(in=inpop) ae(in = inb);
   by &subjid;
   if inpop and inb;
run;

%checkSev;

******Step 2***********;
* Summarize population counts;
proc summary data=pop nway;
   output out=nsubj(drop=_type_ rename=(_freq_=nsubj));
run;


/*PROC REPORT DATA=WORK.nsubj LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title"; */
/*   COLUMN  nsubj;*/
/*   DEFINE  nsubj / group FORMAT= 6. WIDTH=7     SPACING=2   LEFT "# of Participants" order=data;*/
/*   Title "&title";*/
/*   ods proclabel = "&domain";*/
/*RUN;*/
/**/
/*%let title  = Participants By Treatment;*/
/*title "&title";*/
/*proc tabulate data=pop contents="&title";*/
/*   class &treat;*/
/*   table &treat*(n pctn*f=pctfmt7.1);*/
/*   keylabel n = 'Count'*/
/*          pctn = 'Percent';*/
/*   ods proclabel = "&domain";*/
/*run;*/

proc sort data = POP out = pop1(keep =usubjid &trtname);
	by &trtname;
run;
proc sort nodupkey data = pop1 out = trts;
	by &trtname;
run;
%SortRowsByValueOrdering(trts, &treat);
data trts;
	set trts end = eof;
	trtnum = _n_;
	call symput('TRT'||left(_n_), &trtname);
	if eof then call symput('maxtrt', left(_n_));
run;
%let TRT999 = %nrbquote(%LocaleGet(Total_Text));
proc sort data=trts;
	by &treat;
run;
proc sort data=pop1;
	by &treat;
run;
data pop1;
	merge pop1 trts;
	by &treat;
run;
proc sort data = pop1;
	by usubjid;
run;
data subjects(keep = usubjid trtnum int);
	set pop1;
	by usubjid;
	int = 1;
	if first.usubjid;
run;
** Total counts per regimen and overall;
proc means noprint data = subjects;
   class trtnum;
   var int;
   output out = treattots n = n;
run;
data _null_;
   set treattots;
   if trtnum = . then trtnum = 999;
   call symputx("TrtCount"||trim(left(trtnum)),strip(n));
run;
** calculate values in the cells N(%);
proc sort data=subjects;
	by usubjid;
run;
proc sort data=pop;
	by usubjid;
run;
data pop2;
   merge subjects(in = ina) pop(in = inb keep = usubjid &treat) end=eof;
   by usubjid;
   if ina and inb;
   TREATMENTC = "Overall";
   if eof then call symput("vartype", vtype(&treat)); 
run;

proc freq noprint data = pop2;
	tables trtnum*treatmentc / out = stats(drop = pct_row PCT_COL) outpct;
run; 
proc freq noprint data = pop2;
	tables treatmentc / out = statstot outpct;
run; 
** Put regimen-specific and overall numbers together;
data stats1;
	set stats statstot;
	value = catx(" ", count, cats("(",round(percent, 1),")"));
	if trtnum=. then trtnum=999;
	drop count percent;
run;
proc sort data = stats1;
	by treatmentc trtnum;
run;
** PROC REPORT format dataset;
proc transpose data = stats1 out = stats;
	by treatmentc;
	id trtnum;
	var value;
run;

%macro TAB;
%let domain = Adverse Events;
%let title = Participants By Treatment In Study;
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
proc report data = stats(drop = _name_) SPLIT="|" CENTER nowindows missing contents="&Title.";
		   column TREATMENTC ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;) _999;
		   define  TREATMENTC/ id order left "Treatment" style(header)={just=l} style(column)=[cellwidth=19%]; 
		   %do i = 1 %to &maxtrt; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&TRT&i" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&TRT&i" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		   %end; 
		   %if %sysfunc(mod(&maxtrt,5))=0 %then %do;
		      define _999 / page display "&TRT999" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
		   %else %do;
		      define _999 / display "&TRT999" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
	ods proclabel = "&domain";
run;
%MEND TAB;
%TAB;

/*-------------------*/

/*proc summary data=temp(where = (aeterm ne "")) nway;*/
/*   output out=nae(drop=_type_ rename=(_freq_=nae));   */
/*run;*/
/*%let title = Total Adverse Events During Study;*/
/*PROC REPORT DATA=WORK.nae LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&title";   */
/*   COLUMN  nae;*/
/*   DEFINE  nae / group FORMAT= 6. WIDTH=7     SPACING=2   LEFT "# of Adverse Events" order=data;*/
/*   title "&title";*/
/*   ods proclabel = "&domain";       */
/*RUN;*/
/*%let title = Adverse Events By Treatment;*/
/*proc tabulate data=ae contents="&title";*/
/*   class &treat;*/
/*   table &treat*(n pctn*f=pctfmt7.1);*/
/*   keylabel n = 'Count'*/
/*          pctn = 'Percent';*/
/*   title "&title";*/
/*   ods proclabel = "&domain";*/
/*   where aeterm ne "";*/
/*run;*/

proc sort data=TEMP;
	by &treat;
run;
data nae;
	merge temp trts;
	by &treat;
	int=1;
	AE_CHAR = "Overall";
run;
** Total ae per regimen and overall;
proc means noprint data = nae;
   class trtnum;
   var int;
   output out = naetots n = n;
run;
data _null_;
   set naetots;
   if trtnum = . then trtnum = 999;
   call symputx("NAECount"||trim(left(trtnum)),strip(n));
run;
** calculate values in the cells N(%);

proc freq noprint data = nae;
	tables trtnum*ae_char / out = stats(drop = pct_row PCT_COL) outpct;
run; 
proc freq noprint data = nae;
	tables ae_char / out = statstot outpct;
run; 
** Put regimen-specific and overall numbers together;
data stats1;
	set stats statstot;
	value = catx(" ", count, cats("(",round(percent, 1),")"));
	if trtnum=. then trtnum=999;
	drop count percent;
run;
proc sort data = stats1;
	by ae_char trtnum;
run;
** PROC REPORT format dataset;
proc transpose data = stats1 out = stats;
	by ae_char;
	id trtnum;
	var value;
run;

%macro TAB;
%let domain = Adverse Events;
%let title = Adverse Events By Treatment;
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;

proc report data = stats(drop = _name_) SPLIT="|" CENTER nowindows missing contents="&Title.";
		   column ae_char ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;) _999;
		   define  ae_char/ id order left "Treatment" style(header)={just=l} style(column)=[cellwidth=19%]; 
		   %do i = 1 %to &maxtrt; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&TRT&i" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&TRT&i" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		   %end; 
		   %if %sysfunc(mod(&maxtrt,5))=0 %then %do;
		      define _999 / page display "&TRT999" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
		   %else %do;
		      define _999 / display "&TRT999" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
		ods proclabel = "&domain";
run;


/*-------------------*/
%let title = Adverse Events By Relationship To Study Drug;
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
proc freq data=temp order=data;
   tables &advrel /missing nocum  contents="&title";    *don't put cummulative #s;
   title "&title";
   ods proclabel = "&domain";       
run;


%let title = Adverse Events By Severity;
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
proc freq data=temp order=data;
   tables &advsev / nocum contents="&title";    *don't put cummulative #s;
   title "&title";
   ods proclabel = "&domain";       
run;


%let title = Adverse Events By Body System;
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
proc freq data=temp order=data;
   tables &advbs / nocum contents="&title";    *don't put cummulative #s;
   title "&title";
   ods proclabel = "&domain";       
run;


%let title = Adverse Events By Preferred Term;
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
proc freq data=temp order=data;
   tables &advp / nocum contents="&title";    *don't put cummulative #s;
   title "&title";
   ods proclabel = "&domain";       
run;
%MEND TAB;
%TAB;


proc datasets nolist;
   delete temp pop1 pop2 stats1;
quit;

%postProcess;




