/***********************************************
* Patient Population By Treament
* Author:  John Shipway, SAS Institute
* Date:  Dec 12, 2007
* Description:  
* 
*
*************************************************/

%macro TAB;   
   
   %let _tid_ = %sysfunc(open(dm));
   %let _vn_ = %sysfunc(varnum(&_tid_,&TrtName));
   %let _tid_ = %sysfunc(close(&_tid_));    
   
   %if &_vn_ %then %do;
      %let treat=&TrtName;  *treatment group;

/*      * Select patient population; */
/*      data pop;*/
/*         set dm;*/
/*      run;*/
/**/
/*      %let title = Patient Population By Treatment;*/
/*      title "&title";*/
/*      proc tabulate data=pop contents="&title";*/
/*         class &treat;*/
/*         table &treat*(n pctn*f=pctfmt7.1) ALL / */
/*            contents="Table";*/
/*         keylabel n = 'N'*/
/*                pctn = '%';*/
/*         ods proclabel = "Demographics";        */
/*      run;*/

	  /*============ V8 =============*/
	  	proc sort data = &in_adsl out = adsl(keep =usubjid &trtname);
		   by &trtname;
		run;

		proc sort nodupkey data = adsl out = trts;
		   by &trtname;
		run;
		%SortRowsByValueOrdering(trts, &treat);

		data trts;
		  set trts end = eof;
		  trtnum = _n_;
		  call symput('TRT'||left(_n_), &trtname);
		  if eof then call symput('maxtrt', left(_n_));
		run;

		%let TRT999 = %nrbquote(%LocaleGet(Total_Text));

		proc sort data=trts;
			by &treat;
		run;
		proc sort data=adsl;
			by &treat;
		run;
		data adsl;
			merge adsl trts;
			by &treat;
		run;
		proc sort data = adsl;
			by usubjid;
		run;
		data subjects(keep = usubjid trtnum int);
		   set adsl;
		   by usubjid;
		   int = 1;
		   if first.usubjid;
		run;
		** Total counts per regimen and overall;
		proc means noprint data = subjects;
		   class trtnum;
		   var int;
		   output out = treattots n = n;
		run;
		data _null_;
		   set treattots;
		   if trtnum = . then trtnum = 999;
		   call symputx("TrtCount"||trim(left(trtnum)),strip(n));
		run;
		** calculate values in the cells N(%);
		proc sort data=subjects;
			by usubjid;
		run;
		proc sort data=dm;
			by usubjid;
		run;
		data dmex;
		   merge subjects(in = ina) dm(in = inb keep = usubjid age &treat) end=eof;
		   by usubjid;
		   if ina and inb;
		   TREATMENTC = "Overall";
		   if eof then call symput("vartype", vtype(&treat)); 
		run;

		proc freq noprint data = dmex;
		   tables trtnum*treatmentc / out = stats(drop = pct_row PCT_COL) outpct;
		run; 
		proc freq noprint data = dmex;
		   tables treatmentc / out = statstot outpct;
		run; 
		
		** Put regimen-specific and overall numbers together;
		data stats1;
		   set stats /*(rename=(PCT_ROW = percent))*/ statstot;
		   value = catx(" ", count, cats("(",round(percent, 1),")"));
		   if trtnum=. then trtnum=999;
		   drop count percent;
		run;
		proc sort data = stats1;
		   by treatmentc trtnum;
		run;
		** PROC REPORT format dataset;
		proc transpose data = stats1 out = stats;
		   by treatmentc;
		   id trtnum;
		   var value;
		run;
		*** Fill in 0 cells;
		data stats;
		   set stats;
		   %do i = 1 %to &maxtrt;
		      if _&i = "" then  _&i = "0 (0)";
		   %end;
		run;
		/*=============================================*/
		/*================= PROC REPORT ===============*/
		/*=============================================*/

		* Select patient population; 
		%let domain = Demographics;
		%let title = Patient Population By Treatment;
		title "&title"; 
		%if &Output_RTF = Yes %then %do;
		ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
		%END;		
		proc report data = stats(drop = _name_) SPLIT="|" CENTER nowindows missing contents="&Title.";
		
		   column TREATMENTC ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;) _999;
		   define  TREATMENTC/ id order left "Treatment" style(header)={just=l} style(column)=[cellwidth=19%]; 
		   %do i = 1 %to &maxtrt; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		   %end; 
		   %if %sysfunc(mod(&maxtrt,5))=0 %then %do;
		      define _999 / page display "&TRT999||(N=&TrtCount999)" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
		   %else %do;
		      define _999 / display "&TRT999||(N=&TrtCount999)" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
			ods proclabel = "&domain";
		run;
		
   %end;
   %else %do;
      %put ERROR: Patient population by treatment cannot be produced.;
      %put ERROR: Treatment not available.; 
   %end;   
%mend TAB;
%TAB;      

%postProcess;
