/*********************************
* Program: Deaths By Age Stat Analysis, GRP 7.1.1.1
* Author:  John Shipway, SAS Institute
* Date:  December 10, 2007
* Description: Join of DM and DS domains where the disposition = DEATH, means by age
* Todo:
**********************************/

%let treat=&TrtName;  *treatment group;

* Select patient population; 
data pop;
   set dm end = eof;
   if eof then call symput("vartype", vtype(&treat)); 
run;

* merge in ds domain (inner join);
data popds;
   merge pop(in=inpop keep=usubjid age &treat) ds;
   by usubjid;
   if inpop;
run;

* select on DEATH dispositions;
data popdeath;
   set popds;
   where upcase(dsterm) in (&DEATH_TERMS);
run;
%NObsVars(popdeath); *if there's no death, then no tables are created;
%macro TAB;
	%if &nobs %then %do;
		proc sort data=popdeath;
		   by &treat;
		run;

		proc means data=popdeath n nmiss mean median min max std var noprint;
		   var age;
		   by &treat;
		   output out=nagedeath;
		run;

		%let domain = Disposition;
		%let title = Analysis of Age of Patients Who Died During Study;
		%if &Output_RTF = Yes %then %do;
		ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
		%END;
		PROC REPORT DATA=nagedeath LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title."; 

		   COLUMN _stat_ &treat,age;

		   DEFINE  _stat_ / group FORMAT= $6. WIDTH=6     SPACING=2   LEFT "Stat. Function" style(header)={just=l};
		   DEFINE  &treat / across %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=20     SPACING=2 style(header)={just=c}  center "^S={borderbottomcolor=black borderbottomwidth=2} &TrtLabel";  
		   DEFINE  age / FORMAT= 4.1 WIDTH=5     SPACING=2  "Age" order=data style(header)={just=c}  center;

		   title "&title"  color=black;
		   ods proclabel = "&domain";       
		RUN;
		*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	%ELSE %DO; 
		data aa;
			 length note $ 50;
			 note = "No Death During Study";
		run;
			   
		%let domain = Disposition;
		%let title = Analysis of Age of Patients Who Died During Study;
		%if &Output_RTF = Yes %then %do;
		ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
		%END;
		PROC REPORT DATA=aa LS=97  PS=54  SPLIT="|" CENTER nowindows missing contents="&Title.";
			 COLUMN  note;
			 DEFINE  note / group FORMAT= $21. WIDTH=21    SPACING=2   LEFT "Note";
			 title "&title"  color=black;
			 ods proclabel = "&domain";       
		RUN;
		proc datasets nolist;
			 delete aa;
		quit;
	%END;
%mend TAB;
%TAB;

%postProcess;

