/*********************************
* Program: Deaths By Age Group Summary, GRP 7.1.1.1
* Author:  John Shipway, SAS Institute
* Date:  December 10, 2007
* Description: Join of DM and DS domains where the disposition = DEATH, means by age
* Todo:
**********************************/

/*%let treat=&TrtName;  *treatment group;*/
/** Select patient population; */
/*data pop;*/
/*	set dm;*/
/*run;*/
/**/
/** merge in ds domain (inner join);*/
/*data popds;*/
/*	merge pop(in=inpop) ds;*/
/*	by usubjid;*/
/*	if inpop;*/
/*run;*/
/** select on DEATH dispositions;*/
/*data popdeath;*/
/*	set popds;*/
/*	where upcase(dsterm) in (&DEATH_TERMS);*/
/*	if age < 40 then AgeGroup = "39 or less";*/
/*	else if age < 65 then AgeGroup = "40-64";*/
/*	else AgeGroup = "65 & older";*/
/*run;*/
/*%let domain = Disposition;*/
/*%let title = Age Group of Patients Who Died During Study;*/
/*title "&title";*/
/*proc tabulate data=popdeath contents="&title";*/
/*	class AgeGroup &treat;*/
/*	table AgeGroup ALL, &treat*(n pctn) ALL*(n pctn);*/
/*	keylabel n = 'N'*/
/*			 pctn = '%';*/
/*	ods proclabel = "&domain";		 	*/
/*run;*/

/* REFER TO: DM_PATIENT_PROFILES_AGE.sas */
%macro TAB;
   %CHECKPRES(domain = DM, var = AGE);

   %if %length(&AGE) %then %do;
      %let treat=&TrtName;  *treatment group;
		/*============ V8 =============*/
	  	proc sort data = &in_adsl out = adsl(keep =usubjid &trtname);
		   by &trtname;
		run;
		proc sql;
			create table adsl_death as
			select * from adsl
			where usubjid in (select usubjid from ds where upcase(dsterm) in (&DEATH_TERMS));
		quit;

/*		%SYMDEL NOBS;*/
		%NObsVars(adsl_death); 
		/*if there's no death, then no tables are created;*/

		%if &nobs %then %do;
			proc sort nodupkey data = adsl_death out = trts;
			   by &trtname;
			run;
			%SortRowsByValueOrdering(trts, &treat);

			data trts;
			  set trts end = eof;
			  trtnum = _n_;
			  call symput("TRT"||left(_n_), &trtname);
			  if eof then call symput("maxtrt", left(_n_));
			run;

			%let TRT999 = %nrbquote(%LocaleGet(Total_Text));

			proc sort data=trts;
				by &treat;
			run;
			proc sort data=adsl_death;
				by &treat;
			run;
			data adsl_death;
				merge adsl_death trts;
				by &treat;
			run;
			proc sort data = adsl_death;
				by usubjid;
			run;
			data subjects(keep = usubjid trtnum int);
			   set adsl_death;
			   by usubjid;
			   int = 1;
			   if first.usubjid;
			run;
			** Total counts per regimen and overall;
			proc means noprint data = subjects;
			   class trtnum;
			   var int;
			   output out = treattots n = n;
			run;
			data _null_;
			   set treattots;
			   if trtnum = . then trtnum = 999;
			   call symputx("TrtCount"||trim(left(trtnum)),strip(n));
			run;
			** calculate values in the cells N(%);
			proc sort data=subjects;
				by usubjid;
			run;
			proc sort data=dm;
				by usubjid;
			run;
			data dmex;
			   merge subjects(in = ina) dm(in = inb keep = usubjid age &treat) end=eof;
			   by usubjid;
			   if ina and inb;
			   if . < age < 40 then AgeGroup = "39 or less";
			         else if age < 65 then AgeGroup = "40-64";
			         else AgeGroup = "65 & older"; 
			   if eof then call symput("vartype", vtype(&treat)); 
			run;
			proc sort data=dmex;
				by usubjid AgeGroup;
			run;

			proc freq noprint data = dmex;
			   tables trtnum * AgeGroup / out = stats(drop = percent PCT_COL) outpct;
			run; 
			proc freq noprint data = dmex;
			   tables AgeGroup / out = statstot;
			run;
			** Put regimen-specific and overall numbers together;
			data stats1;
			   set stats(rename=(PCT_ROW = percent)) statstot;
			   value = catx(" ", count, cats("(",round(percent, 1),")"));
			   if trtnum=. then trtnum=999;
			   drop count percent;
			run;
			proc sort data = stats1;
			   by AgeGroup trtnum;
			run;
			** PROC REPORT format dataset;
			proc transpose data = stats1 out = stats;
			   by AgeGroup;
			   id trtnum;
			   var value;
			run;
			*** Fill in 0 cells;
			data stats;
			   set stats;
			   %do i = 1 %to &maxtrt;
			      if _&i = "" then  _&i = "0 (0)";
			   %end;
			run;

			/*=============================================*/
			/*================= PROC REPORT ===============*/
			/*=============================================*/

			* Select patient population; 
			%let domain = Disposition;
			%let title = Age Group of Patients Who Died During Study;
			title "&title"  color=black; 
			%if &Output_RTF = Yes %then %do;
			ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
			%END;
			proc report data = stats(drop = _name_) SPLIT="|" CENTER nowindows missing contents="&Title.";
			   column AgeGroup ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;) _999;
			   define AgeGroup / id order left "AgeGroup" style(header)={just=l} style(column)=[cellwidth=19%]; 
			   %do i = 1 %to &maxtrt; 
			      %if %sysfunc(mod(&i,6))=0 %then %do;
			         define _&i / page display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
			      %end;
			      %else %do;
			         define _&i / display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
			      %end;
			   %end; 
			   %if %sysfunc(mod(&maxtrt,5))=0 %then %do;
			      define _999 / page display "&TRT999||(N=&TrtCount999)" style(column)=[cellwidth=9%] style(header)={just=l};
			   %end;
			   %else %do;
			      define _999 / display "&TRT999||(N=&TrtCount999)" style(column)=[cellwidth=9%] style(header)={just=l};
			   %end;
			   ods proclabel = "&domain"; 
			run;
			*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
		%END; 
		%ELSE %DO;  
			data aa;
		        length note $ 50;
		        note = "No Death During Study";
		    run;
		   
		    %let domain = Disposition;
			%let title = Age Group of Patients Who Died During Study;
			%if &Output_RTF = Yes %then %do;
			ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
			%END;
			PROC REPORT DATA=aa LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title." ;
		         COLUMN  note;
		         DEFINE  note / group FORMAT= $21. WIDTH=21    SPACING=2   LEFT "Note";
		         title "&title";
		         ods proclabel = "&domain";       
		      RUN;
		      
		      proc datasets nolist;
		         delete aa;
		      quit;
		%END;  

   %end; 
   %else %do;
      %put ERROR: Patient population by age cannot be produced.;
      %put ERROR: Age not available.; 
   %end;   
%mend TAB;
%TAB;

%postProcess;
