/*********************************

Deaths Listing, GRP 7.1.1.1

Author:  John Shipway, SAS Institute

Date:  December 10,  2007

Description: Join of DM and DS domains where the disposition = DEATH

Todo:
       Need to implement Source and Person time columns of 7.1.1.1.
	   Also the description if it is available

	   Could also summarize deaths by age group, treatment, sex, time in study

*********************************/

%let treat=&TrtName;  *treatment group;

*the following will set the STUDY library name with the correct directory;
*%include "&SInPath.STUDY_LOCATION.sas";


* Select patient population; 
data pop(keep=usubjid age sex siteid &treat);
	set &in_adsl end = eof;
	if eof then call symput("vartype", vtype(&treat)); 
run;
proc sort data=pop; by usubjid; run;

* merge in ds domain (inner join);
data popds;
	merge pop(in=inpop) ds;
	by usubjid;
	if inpop;
run;
  
* select on DEATH dispositions;
data popdeath;
	set popds;
	where upcase(dsterm) in (&DEATH_TERMS);
/*	if missing(DSSTDY) then do;
		%calcStudyDay(DSSTDTC);
	end; */
run;

%NObsVars(popdeath); *if there's no death, then no tables are created;
%macro TAB;
%if &nobs %then %do;
	proc sort data=popdeath;
		by &treat;
	run;

	proc means data=popdeath noprint;
		var stdy; *** DSSTDY OR STDY?????;
		by &treat;
		output out=ndaysdeath;
	run;

	
	%let domain = Disposition;
	%let title = Analysis of Number of Study Days before Death;
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	PROC REPORT DATA=ndaysdeath LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title."; 

		COLUMN _stat_ &treat, stdy;

		DEFINE  _stat_ / group FORMAT= $6. WIDTH=6     SPACING=2   LEFT "Stat. Function" style(header)={just=l};
		DEFINE  &treat / across %if &vartype = C %then %do; FORMAT= $25. %end; WIDTH=20 SPACING=2  "^S={borderbottomcolor=black borderbottomwidth=1} &TrtLabel" style(header)={just=c};	
		DEFINE  stdy / FORMAT= 4.1 WIDTH=5     SPACING=2  "Study Days" order=data style(header)={just=c}  center;
	   title "&title" color=black;
		*ods proclabel = "&domain";		 	
	RUN;
	*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
%ELSE %DO; 
	data aa;
		 length note $ 50;
		 note = "No Death During Study";
	run;
		   
	%let domain = Disposition;
	%let title = Analysis of Number of Study Days before Death;
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	PROC REPORT DATA=aa LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";
		 COLUMN  note;
		 DEFINE  note / group FORMAT= $21. WIDTH=21    SPACING=2   LEFT "Note";
		 title "&title";
		 ods proclabel = "&domain";       
	RUN;
	proc datasets nolist;
		 delete aa;
	quit;
%END; 
%mend TAB;

%TAB;

%postProcess;






