/*********************************
* Deaths Listing, GRP 7.1.1.1
* Author:  John Shipway, SAS Institute
* Date:  December 10,  2007
* Description: Join of DM and DS domains where the disposition = DEATH
* Todo:
*      Need to implement Source and Person time columns of 7.1.1.1.
*     Also the description if it is available
*     Could also summarize deaths by age group, treatment, sex, time in study
*
*********************************/


%let treat=&TrtName;  *treatment group;

* Select patient population; 
data pop;
   set dm end = eof;
   if eof then call symput("vartype", vtype(&treat)); 
run;

* merge in ds domain (inner join);
data popds;
   merge pop(in=inpop keep=usubjid age sex siteid &treat rfstdtc) ds;
   by usubjid;
   if inpop;
run;
  
* select on DEATH dispositions;
data popdeath;
   set popds;
   where upcase(dsterm) in (&DEATH_TERMS);
   /* if missing(DSSTDY) then do;
      %calcStudyDay(DSSTDTC);
   end; */
run;
%NObsVars(popdeath); 
/**if there's no death, then no tables are created;*/

%macro TAB;
*report results;
%if &nobs %then %do;
	%let domain = Disposition;
	%let title = Deaths Listing;
	%let title2 = GRP Table 7.1.1.1;
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	PROC REPORT DATA=popdeath LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&TITLE."; 

	   COLUMN STUDYID siteid USUBJID AGE SEX &treat STDY ; *need 2 more columns, maybe a third;

	   DEFINE  STUDYID / FORMAT= $&studlen.. WIDTH=7     SPACING=2   LEFT "Trial" style(header)={just=l};
	   DEFINE  siteid / FORMAT= $&sitelen.. WIDTH=10     SPACING=2   LEFT "Center" style(header)={just=l};
	   DEFINE  USUBJID / FORMAT= $&sublen.. WIDTH=7     SPACING=2   LEFT "Patient" order=data style(header)={just=l};
	   DEFINE  AGE / FORMAT= 5. WIDTH=7     SPACING=2   LEFT "Age" order=data style(header)={just=l};
	   DEFINE  SEX / FORMAT= $3. WIDTH=3     SPACING=2   LEFT "Sex" order=data style(header)={just=l};
	   DEFINE  &treat / %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=7     SPACING=2   LEFT "&TrtLabel" order=data style(header)={just=l};
	   DEFINE  STDY / FORMAT= 5. WIDTH=7     SPACING=2   LEFT "Time" order=data style(header)={just=l};

	   TITLE "&title";
	   TITLE2 "&title2";
	   ods proclabel = "&domain";       
	RUN;
	*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
%ELSE %DO;  
	data aa;
		 length note $ 50;
		 note = "No Death During Study";
	run;
		   
	%let domain = Disposition;
	%let title = Deaths Listing;
	%let title2 = GRP Table 7.1.1.1;
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	PROC REPORT DATA=aa LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&TITLE.";
		 COLUMN  note;
		 DEFINE  note / group FORMAT= $21. WIDTH=21    SPACING=2   LEFT "Note";
		 title "&title"; 
		 TITLE2 "&TITLE2.";
		 ods proclabel = "&domain";       
	RUN;
	proc datasets nolist;
		 delete aa;
	quit;
%END;  
%mend TAB;
%TAB;

%postProcess;

