/*************************************
* Program: Dropout Profile by Treatment Group and Reason
* Author:  John Shipway, SAS Institute
* Date:  December 10, 2007;
* Description: 
*
* Todo:  Incorporate Cutoff date, how would this be done.
**************************************/

%macro DROPPROF;
   %let treat=&TrtName;  *treatment group;

   *this is the DSTERM in the DS Table that signifies the subject completing the study;
   *we are going to select out these entries;
   %let COMPLETION_TERM = "PROTOCOL COMPLETED";
   %let DEATH_TERM = "DEATH";

   %let DSCAT = ;
   %if %sysfunc(findw(&domains, DS)) %then %do;
      %if %sysfunc(findw(%upcase(&DSVARS), DSCAT)) %then %let DSCAT = DSCAT;
   %end;
   %let DSDECOD = ;
   %if %sysfunc(findw(&domains, DS)) %then %do;
      %if %sysfunc(findw(%upcase(&DSVARS), DSDECOD)) %then %let DSDECOD = DSDECOD;
   %end;

   %let trDispositionEvent = %nrbquote(%LocaleGet(DispositionEvent_Text));

   %if %length(&DSCAT) and %length(&DSDECOD) %then %do;
      * Select patient population; 
      data pop(keep=usubjid &treat);
         set &in_adsl;
      run;

      * get dropouts;
      proc sort data=ds; by usubjid; run;
      data drop;
         set ds; 
         by usubjid;
         where dsdecod not in (&COMPLETION_TERM, "COMPLETED") /* and dsdecod ne &DEATH_TERM */         
         and upcase(DSCAT) = "%upcase(&trDispositionEvent)"
         ;
         if last.usubjid;
      run;

      *get population that dropped out;
	  proc sort data=pop; by usubjid; run;
	  proc sort data=drop; by usubjid; run;
      data popdrop;
         merge pop(in=inpop) drop(in=inb);
         by usubjid;
         if inpop and inb;
      run;
/*      %let domain = Disposition;*/
/*      %let title = Dropout Profile: Incidence of Dropout by Treament Group and Reason;*/
/*      title "&title";*/
/*      title2 "Table 7.1.3.1.1 of the GRP";*/
/*      proc tabulate data=popdrop contents="&title";*/
/*         class dsdecod &treat;*/
/*         table dsdecod ALL, &treat*(n pctn) ALL;*/
/*         ods proclabel = "&domain";       */
/*      run;        */

		/*============ V8 =============*/
	  	proc sort data = popdrop out = pop1(keep =usubjid &trtname);
		   by &trtname;
		run;

		proc sort nodupkey data = pop1 out = trts;
		   by &trtname;
		run;
		%SortRowsByValueOrdering(trts, &treat);

		data trts;
		  set trts end = eof;
		  trtnum = _n_;
		  call symput('TRT'||left(_n_), &trtname);
		  if eof then call symput('maxtrt', left(_n_));
		run;

		%let TRT999 = %nrbquote(%LocaleGet(Total_Text));

		proc sort data=trts;
			by &treat;
		run;
		proc sort data=pop1;
			by &treat;
		run;
		data pop1;
			merge pop1 trts;
			by &treat;
		run;
		proc sort data = pop1;
			by usubjid;
		run;
		data subjects(keep = usubjid trtnum int);
		   set pop1;
		   by usubjid;
		   int = 1;
		   if first.usubjid;
		run;
		** Total counts per regimen and overall;
		proc means noprint data = subjects;
		   class trtnum;
		   var int;
		   output out = treattots n = n;
		run;
		data _null_;
		   set treattots;
		   if trtnum = . then trtnum = 999;
		   call symputx("TrtCount"||trim(left(trtnum)),strip(n));
		run;
		** calculate values in the cells N(%);
		proc sort data=subjects;
			by usubjid;
		run;
		proc sort data=popdrop;
			by usubjid;
		run;
		data popdrop;
		   merge subjects(in = ina) popdrop(in = inb keep = usubjid dsdecod &treat) end=eof;
		   by usubjid;
		   if ina and inb;
		   if eof then call symput("vartype", vtype(&treat)); 
		run;
		proc sort data=popdrop;
			by trtnum usubjid dsdecod;
		run;

		proc freq noprint data = popdrop;
		   by trtnum;
		   tables dsdecod / out = stats(drop = pct_row PCT_COL) outpct;
		run; 
		proc freq noprint data = popdrop;
		   tables dsdecod / out = statstot;
		run;
		** Put regimen-specific and overall numbers together;
		data stats1;
		   set stats statstot;
		   value = catx(" ", count, cats("(",round(percent, 1),")"));
		   if trtnum=. then trtnum=999;
		   drop count percent;
		run;
		proc sort data = stats1;
		   by dsdecod trtnum;
		run;
		** PROC REPORT format dataset;
		proc transpose data = stats1 out = stats;
		   by dsdecod;
		   id trtnum;
		   var value;
		run;
		*** Fill in 0 cells;
		data stats;
		   set stats;
		   if dsdecod ^="";
		   %do i = 1 %to &maxtrt;
		      if _&i = "" then  _&i = "0 (0)";
		   %end;
		run;
		/*=============================================*/
		/*================= PROC REPORT ===============*/
		/*=============================================*/

		* Select patient population; 
		%let domain = Disposition;
	    %let title = Dropout Profile: Incidence of Dropout by Treament Group and Reason;
	    title "&title";
	    title2 "Table 7.1.3.1.1 of the GRP";
	  	%if &Output_RTF = Yes %then %do;
		ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
		%END;
		proc report data = stats(drop = _name_) SPLIT="|" CENTER nowindows missing contents="&Title.";
		   column dsdecod ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;) _999;
		   define dsdecod / id order left "Standardized Disposition Term" style(header)={just=l} style(column)=[cellwidth=19%]; 
		   %do i = 1 %to &maxtrt; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		   %end; 
		   %if %sysfunc(mod(&maxtrt,5))=0 %then %do;
		      define _999 / page display "&TRT999||(N=&TrtCount999)" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
		   %else %do;
		      define _999 / display "&TRT999||(N=&TrtCount999)" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
		   ods proclabel = "&domain";   
		run;
		*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
 
   %end;
   %else %do;
      %put ERROR: DSVARS and DSCDECOD are not available. Dropout Group and Reason Table is not available.;
      %let exiterror = 1;
   %end;
%mend DROPPROF;
%DROPPROF;

proc datasets nolist; 
	delete pop pop1 stats stats1 statstot subjects treattots;
run;
quit;

%postProcess;

