/*************************************
Mortality by Treatment Group
Author:  John Shipway, SAS Institute
Date:  December 10, 2007;
Description: 

Todo: 1) merge between ds and dm needs to consider that there may be usubjids in 
        ds that don't exist in dm...this will affect the counts.       
**************************************/

%let treat=&TrtName;  *treatment group;

* Select patient population; 
data pop;
   set dm end = eof;
   if eof then call symput("vartype", vtype(&treat)); 
run;

proc summary data=pop(keep=usubjid &treat);
   class &treat;
   output out=nsubjarm(drop=_type_ rename=(_freq_=npop));
run;

data death; 
   set ds;
   where upcase(dsterm)="DEATH";
run;

data deatharm;
   merge death(in=indeath) pop;
   by usubjid;
   if indeath;
run;

proc summary data=deatharm nway noprint;
   class &treat;
   output out=deathsummary(drop=_type_ rename=(_freq_=ndeath));
run;

%macro TAB;
data totals;
   merge nsubjarm deathsummary;
   mortality = ndeath / npop;
   by &treat;
   %if &vartype = C %then %do; 
      where &treat <> '';
   %end;
   %else %do;
      where &treat > .;
   %end;
run;

%let domain = Disposition;
%let title = Mortality By Treatment Group;

%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
PROC REPORT DATA=WORK.totals LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";   
   COLUMN  &treat npop ndeath mortality;
   DEFINE  &treat / %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=7     SPACING=2   LEFT "&TrtLabel" order=data style(header)={just=l};
   DEFINE  npop / FORMAT= BEST9. WIDTH=9 SPACING=2   LEFT "Total # of Patients" ;
   DEFINE  ndeath / FORMAT= BEST9. WIDTH=9 SPACING=2 LEFT "Total # of Deaths" ;
   DEFINE  mortality / FORMAT = NUM.2 WIDTH=9 SPACING=2 LEFT "Crude Mortality" ;
   Title "&title";
   Title2 "Table 7.1.1.2 of the GRP";
   ods proclabel = "&domain";       
RUN;
*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%mend TAB;
%TAB;

%postProcess;


