/*************************************
Mean Change from Baseline for Serum Chemistry Parameters
Author:  John Shipway, SAS Institute
Date:  December 18, 2007;
Description: 

todo: need to figure out
**************************************/

%macro MCB;
%if %sysfunc(findw(%upcase(&LBVARS), %upcase(LBBLFL))) %then %do;
   %let treat=&TrtName;  *treatment group;

   proc sort data=&in_adsl out=trts(keep =usubjid &trtname); by usubjid; run;
   proc sort data=lb; by usubjid; run;
   data lb;
   		merge lb(in=inlb) trts;
		by usubjid;
		if inlb;
	run;

   *get baseline values for labs;
   data labbase(keep=usubjid lbtest &treat lbblfl result1); *TREATMENT IS NOT AVAILBLE IN LB;
      *set admstudy.adlbc;
      set lb end = eof;
      *check baseline flag;
      where lbblfl = 'Y';
      result1 = lbstresn;
      if eof then call symput("vartype", vtype(&treat));    
   run;

   proc sort data=labbase;
      by usubjid lbtest &treat;
   run;

   *get trt values for labs;
   data labtrt(keep=usubjid lbtest &treat lbblfl resultn);
      *set admstudy.adlbc;
      set lb;
      * where lbtrtefl = 'Y';   
      where lbblfl ne 'Y';   *on-trt labs;
      resultn = lbstresn;
   run;

   proc sort data=labtrt;
      by usubjid lbtest &treat;
   run;

   data labmerge;
      merge labbase(in=InBase) labtrt(in=InTrt);
      by usubjid lbtest;
      dif = result1 - resultn;
      percentageChange = dif / result1 * 100;
      if inBase and InTrt;
   run;


   proc sort data=labmerge;
      by lbtest &treat;
   run;


   proc summary data=labmerge;
      by lbtest &treat;
      var result1 dif percentageChange;
      output out = labsummary(drop=_type_ rename=(_freq_=nsubj1));
   run;


   data meansummary;
      set labsummary;
      if _stat_ = "MEAN";
   run;


   %macro TAB;
   %let domain = Labs;
   %let title = Mean Change from Baseline for Serum Chemistry Parameters; 
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;

   PROC REPORT DATA=WORK.meansummary LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";

      COLUMN  lbtest &treat,(nsubj1 result1 dif percentageChange);

      DEFINE  lbtest /id GROUP FORMAT= $&lbtestlen.. style(column)=[cellwidth=10%]  SPACING=2   LEFT "Lab Test" order=data style(header)={just=l};      
      DEFINE  &treat / ACROSS %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=28  SPACING=2  LEFT "&TrtLabel";
      DEFINE  nsubj1 / FORMAT=5.0 			WIDTH=6     SPACING=2  left "N" style(header)={just=l};
      DEFINE  result1 / FORMAT=5.4 			WIDTH=6     SPACING=2  left "Baseline" style(header)={just=l};
      DEFINE dif / format=5.2  				width=6 	SPACING=2 left "Difference" style(header)={just=l};
      DEFINE percentageChange / format=5.2  width=6 	SPACING=2 left "% Change" style(header)={just=l};
      title "&title";
      title2 "GRP Table 7.1.7.3.1.1";
      ods proclabel = "&domain";       
   RUN;
   *ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
   %mend TAB;
   %TAB;
   %postProcess;
%end;
%else %do;
   %let title = Mean Change from Baseline for Serum Chemistry Parameters;   
   /*%if &Output_RTF = Yes %then %do;
      ods rtf text="LBBLFL not available. &title not generated.";
   %end;

   %if &Output_PDF = Yes %then %do;
      ods pdf text="LBBLFL not available. &title not generated.";
   %end;

   %if &Output_HTML = Yes %then %do;
      ods html text="LBBLFL not available. &title not generated.";
   %end;*/  
   data aa;
      length text $ 200;
      text = "LBBLFL not available. &title not generated.";
      label text = "Note:";
   run;
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
   proc print noobs label data = aa contents="&Title.";
         ods proclabel = "&domain";       
   run;  
%end;
%mend MCB;
%MCB;
