/*************************************
Comparison of Mean Serum Chemistry Parameters Between two Visits (1 and n)
Author:  John Shipway, SAS Institute
Date:  December 18, 2007;
Description: Note, in the labn data set, you specify the visit number you want 
             From a comparison standpoint.  You could change lab1's visit parm as well.

**************************************/

options nofmterr nosymbolgen;

%let treat=&TrtName;  *treatment group;

* Select patient population; 
data pop(keep=usubjid &treat);
   set &in_adsl end = eof;
   if eof then call symput("vartype", vtype(&treat));    
run;

data lab(keep=usubjid lbtest lbstresn lbdtc visitnum);
   set lb;
run;
proc sort data=pop; by usubjid; run;
proc sort data=lab; by usubjid; run;

data labpop;
   merge pop(in=inpop) lab;
   by usubjid;
   if inpop;
run;

data lab1(keep=usubjid &treat lbtest lbstresn visitnum result1);
   set labpop;
   result1 = lbstresn;
   where visitnum=1;
run;

proc sort data = lab1;
   by lbtest &treat;
run;


proc summary data=lab1 n mean;
   by lbtest &treat;
   var result1;
   output out = lab1summary(drop=_type_ rename=(_freq_=nsubj1));  
run;

proc sort data=lab1summary;
   by lbtest &treat _stat_;
run;


data labn(keep=usubjid &treat lbtest lbstresn visitnum  resultn);
   set labpop;
   resultn = lbstresn;
   where visitnum=&VISITN;
run;


proc sort data = labn;
   by lbtest &treat;
run;


proc summary data=labn n mean;
   by lbtest &treat;
   var resultn;
   output out = labnsummary(drop=_type_ rename=(_freq_=nsubjn));  
run;


proc sort data=labnsummary;
   by lbtest &treat _stat_;
run;


data labsummary;
   merge lab1summary labnsummary;
   by lbtest &treat _stat_;
   where _stat_ eq 'N' or _stat_ eq 'MEAN';
   dif = result1 - resultn;
run;


/*
title "Comparison of Mean Serum Chemistry Parameters Between two Visits (1 and n)";
proc tabulate data=labsummary;
   class lbtest &treat _stat_;
   var resultn; * resultn;
   table lbtest,&treat*resultn*mean; * &treat*resultn*mean;
run;
*/

data reportdata;
   set labsummary;
run;

%macro TAB;
%let domain = Labs;
%let title = Comparison of Mean Serum Chemistry Parameters Between Two Visits (1 and &VISITN);
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;


PROC REPORT DATA=WORK.reportdata LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";

   COLUMN  lbtest _stat_,&treat,(result1 resultn dif);
    *COLUMN  &advbs &ADVP  &treat,( COUNT PCT_COL) xp2_fish;

   DEFINE  lbtest / id GROUP FORMAT= $&lbtestlen.. WIDTH=28    SPACING=2   LEFT "Lab Test" order=data style(header)={just=l};      
   DEFINE  _stat_ / ACROSS FORMAT= $25. WIDTH=25     SPACING=2   RIGHT "Stat" ;
   DEFINE  &treat / ACROSS %if &vartype = C %then %do; FORMAT= $&armlen.. %end; WIDTH=10    SPACING=2   LEFT "&TrtLabel" ;
   DEFINE  result1 / FORMAT=5.4 WIDTH=9     SPACING=2  left "Visit 1" style(header)={just=l};
   Define  resultn / format=5.4  width=9 SPACING=2 left "Visit &VISITN" style(header)={just=l};
   DEFINE dif / format=5.2  width=9 SPACING=2 left "Difference" style(header)={just=l};
   title "&title";
   ods proclabel = "&domain";       
RUN;
*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%mend TAB;
%TAB;

%postProcess;

