/*************************************
Mean Values for Baseline and Worst Measurement for Serum Chemistry Parameters
Author:  John Shipway, SAS Institute
Date:  December 18, 2007;
Description: 

This takes the mean baseline value and the mean "worst" value and compares them
for each treatment group, for each serum chemistry parameter.
**************************************/

%macro MCB;
%if %sysfunc(findw(%upcase(&LBVARS), %upcase(LBBLFL))) %then %do;
   %let treat=&TrtName;  *treatment group;

   *get baseline values for labs;
   data labbase;
      *set admstudy.adlbc;
      set lb end = eof;
      *check baseline flag;
      where lbblfl = 'Y';
      result1 = lbstresn;
      if eof then call symput("vartype", vtype(&treat)); 
   run;


   proc sort data=labbase;
      by lbtest &treat;
   run;

   proc summary data=labbase n mean;
      by lbtest &treat;
      var result1;
      output out = basesummary(drop=_type_ rename=(_freq_=nsubj1));  
   run;

   data basesummary;
      set basesummary;
      where _stat_ eq 'MEAN'; 
   run;

   proc sort data=basesummary;
      by lbtest &treat;
   run;

   data labworst;
      *set admstudy.adlbc;
      set lb;
      * where lbtrtefl = 'Y';   
      where lbblfl ne 'Y';   
      resultn = lbstresn;
   run;

   proc sort data=labworst;
      by lbtest &treat;
   run;

   proc summary data=labworst n max;
      by lbtest &treat;
      var resultn;   
      output out = worstsummary(drop=_type_ rename=(_freq_=nsubj1));
   run;

   data worstsummary;
      set worstsummary;
      where _stat_ eq 'MAX';
   run;


   proc sort data=worstsummary;
      by lbtest &treat;
   run;


   data labsummary;
      merge basesummary worstsummary;
      by lbtest &treat;
      dif = result1 - resultn;
      percentageChange = dif / result1 * 100;
   run;


   data reportdata;
      set labsummary;
   run;

   %macro TAB;
   %let domain = Labs;
   %let title = Mean Values for Baseline and Worst Measurement for Serum Chemistry Parameters;

%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;

	PROC REPORT DATA=WORK.reportdata LS=97  PS=54  SPLIT="/" CENTER nowindows missing contents="&Title.";

      COLUMN  lbtest &treat,(nsubj1 result1 resultn dif percentageChange);

      DEFINE  lbtest /id GROUP FORMAT= $&lbtestlen.. style(column)=[cellwidth=10%] SPACING=2   LEFT "Lab Test" order=data style(header)={just=l};      
      DEFINE  &treat / ACROSS %if &vartype = C %then %do; FORMAT= $&armlen.. %end;  LEFT "&TrtLabel"; * WIDTH=28  SPACING=3 style(column)=[cellwidth=25%] ;
      DEFINE  nsubj1 / FORMAT=5.0 WIDTH=6   SPACING=2  left "N" style(header)={just=l};
      DEFINE  result1 / FORMAT=5.4 WIDTH=6  SPACING=2  left "Baseline" style(header)={just=l};
      Define  resultn / format=5.4 WIDTH=6 SPACING=2 left "Worst Value" style(header)={just=l};
      DEFINE dif / format=5.2  WIDTH=6 SPACING=2 left "Difference" style(header)={just=l};
      DEFINE percentageChange / format=5.2  WIDTH=6 SPACING=2 left "% Change" style(header)={just=l};
      title "&title";
      ods proclabel = "&domain";       
   RUN;
   *ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
   %mend TAB;
   %TAB;
%end;
%else %do;
   %let title = Mean Values for Baseline and Worst Measurement for Serum Chemistry Parameters;   
	%if &Output_RTF = Yes %then %do;
	ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
	%END;
	data aa;
      length text $ 200;
      text = "LBBLFL not available. &title not generated.";
      label text = "Note:";
   run;
   proc print noobs label data = aa contents="&Title.";
   run;  
   *ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%end;
%mend MCB;
%MCB;



