/***********************************************
* Patient Population By Sex
* Author:  John Shipway, SAS Institute
* Date:  Dec 12, 2007
* Description:  
* 
*
*************************************************/

%macro MHREPORT;
%let treat=&TrtName;  *treatment group;

		proc sort data = &in_adsl out = adsl(keep =usubjid &trtname);
		   by &trtname;
		run;

		proc sort nodupkey data = adsl out = trts;
		   by &trtname;
		run;
		%SortRowsByValueOrdering(trts, &treat);

		data trts;
		  set trts end = eof;
		  trtnum = _n_;
		  call symput('TRT'||left(_n_), &trtname);
		  if eof then call symput('maxtrt', left(_n_));
		run;

		%let TRT999 = %nrbquote(%LocaleGet(Total_Text));

		proc sort data=trts;
			by &treat;
		run;
		proc sort data=adsl;
			by &treat;
		run;
		data adsl;
			merge adsl trts;
			by &treat;
		run;
		proc sort data = adsl;
			by usubjid;
		run;
		data subjects(keep = usubjid trtnum int);
		   set adsl;
		   by usubjid;
		   int = 1;
		   if first.usubjid;
		run;
		** Total counts per regimen and overall;
		proc means noprint data = subjects;
		   class trtnum;
		   var int;
		   output out = treattots n = n;
		run;
		data _null_;
		   set treattots;
		   if trtnum = . then trtnum = 999;
		   call symputx("TrtCount"||trim(left(trtnum)),strip(n));
		run;

* Select patient population; 
/*data pop(keep=usubjid &treat);*/
/*	set dm;*/
/*run;*/
/**/
/*proc sort data=pop;*/
/*	by &treat;*/
/*run;*/

%if %sysfunc(findw(%upcase(&MHVARS), MHDECOD)) %then %let mhvar = mhdecod;
%else %if %sysfunc(findw(%upcase(&MHVARS), MHTERM)) %then %let mhvar = mhterm;

*get arm counts;
/*proc summary data=pop nway;*/
/*	class &treat;*/
/*	output out=narm(drop=_type_);*/
/*run;*/

proc sort data=SUBJECTS;
	by usubjid;
run;
 
* get merged history;
data history;
	merge mh SUBJECTS;
	by usubjid;
	int = 1;
run;

*** get unique instances of each history term per subject ***;
proc sort nodupkey data=history;
	by TRTNUM &mhvar usubjid;
run;

/*proc summary data=history;*/
/*	by TRTNUM &mhvar;*/
/*	var int;*/
/*	output out = historysummary(drop=_type_);*/
/*run;*/
/**/
/*data historysummarycount;*/
/*	set historysummary;*/
/*	where _stat_='N';*/
/*run;*/

proc freq noprint data = history;
	tables trtnum * &mhvar. / out = stats ;
run; 
proc freq noprint data = history;
	tables &mhvar./ out = statstot;
run;
data stats1;
	set stats statstot;
/*	if trtnum=. then trtnum=999;*/
	drop percent;
run;
proc sort data = stats1;
	by trtnum;
run;

proc sort data=treattots; by trtnum; run;

data hswithtotals;
	merge stats1 treattots(keep=trtnum n);
	by TRTNUM;
/*	if &mhvar. ^="";*/
	pct = round(count/n*100,1);
	value = catx(" ",count,cats("(",pct,")"));
	if trtnum=. then trtnum=999;
run;

proc sort data=hswithtotals nodup; by &mhvar.; run;
proc transpose data = hswithtotals out = stats;
	by &MHVAR;
	id trtnum;
	var value;
run;
data stats;
	set stats;
	%do i = 1 %to &maxtrt;
		if _&i = "" then  _&i = "0 (0)";
	%end;
run;

		/*=============================================*/
		/*================= PROC REPORT ===============*/
		/*=============================================*/

%let domain = Medical History;
%let title = Medical History Summary;	
title "&title";
/*proc tabulate data=history contents="&title";*/
/*	class &mhvar &treat;*/
/*	table &mhvar ALL, &treat*(n pctn) ALL*(n pctn);*/
/*	keylabel n = 'N'*/
/*			 pctn = '%';*/
/*	ods proclabel = "&domain";		 	*/
/*run;*/
%if &Output_RTF = Yes %then %do;
ODS RTF PREPAGE ="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";
%END;
proc report data = stats(drop = _name_) SPLIT="|" CENTER nowindows missing contents="&TITLE.";
	column &mhvar. ("^S={borderbottomcolor=black borderbottomwidth=2} &trtlabel" %do i = 1 %to &maxtrt; _&i %end;) _999;
	define &mhvar. / id order left "Dictionary Derived Term" style(header)={just=l} style(column)=[cellwidth=15%]; 
		   %do i = 1 %to &maxtrt; 
		      %if %sysfunc(mod(&i,6))=0 %then %do;
		         define _&i / page display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		      %else %do;
		         define _&i / display "&&TRT&i||(N=&&TrtCount&i)" style(column)=[cellwidth=9%] style(header)={just=l}; 
		      %end;
		   %end; 
		   %if %sysfunc(mod(&maxtrt,5))=0 %then %do;
		      define _999 / page display "&TRT999||(N=&TrtCount999)" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
		   %else %do;
		      define _999 / display "&TRT999||(N=&TrtCount999)" style(column)=[cellwidth=9%] style(header)={just=l};
		   %end;
	ods proclabel = "&domain";
run;
*ods rtf text="^S={outputwidth=100% just=l} {\tc\f3\fs0\cf8 &domain. : &Title.}";

%postProcess;
%mend MHREPORT;
%MHREPORT;
