
/***************************************************************
JMP Clinical Macro

Name: Domain Distribution
Support: Kelci Miclaus, SAS Institute Inc.

Description: 
      Macro for analysis processing for AE, Events and Interventions distribution reports. 

-----------------------------------------------------------
Copyright (C) 2010 SAS Institute, Inc. All rights reserved. 

Notice: 
The above copyright notice and this notice must appear in
any whole or partial copy of this code and any related
documentation. Permission to use, copy, and modify the
source code contained in this file is hereby granted, but
is limited to customers of SAS with a valid license for the
SAS software product with which this file was provided. 
Except as expressly set forth herein, the terms of such
license apply.
-----------------------------------------------------------
****************************************************************/


/*
$CVS_START$
$ID: ADSLDistributionOptions$
$CMP: OOUT$ $UE: DM.AGE$ $NOTES: Variable will be available in Data Filter and Distributions.$
$CMP: OOUT$ $UE: DM.SEX$ $NOTES: Variable will be available in Demographic Grouping, Data Filter, and Distributions.$
$CMP: OOUT$ $UE: DM.RACE$ $NOTES: Variable will be available in Demographic Grouping, Data Filter, and Distributions.$
$CMP: OOUT$ $UE: DM.SITEID$ $NOTES: Variable will be available in Demographic Grouping, Data Filter, and Distributions.$
$CMP: OOUT$ $UE: DM.COUNTRY$ $NOTES: Variable will be available in Demographic Grouping, Data Filter, and Distributions.$
$CMP: OOUT$ $UE: DM.STUDYID$ $NOTES: Use like other demography only if multiple levels deteced indicating a multi-study analysis.$
$CVS_STOP$
*/

%macro DomainDistribution(domain,fillmissingVars=,countplotVars=,stackVars=,distributionVars=,customFilterVars = ,doTreatmentRRs = 0,UseGroups = 0, doRates = 0);
   /*Create Translation Labels*/
   %let tclabel = %nrbquote(%LocaleGet(TotalCount_Text));
   %let gclabel = %nrbquote(%LocaleGet(GroupCount_Text));
   %let polabel = %nrbquote(%LocaleGet(PercentOccurrence_Text));
   %let TGpolabel = %nrbquote(%LocaleGet(MaxTreatmentGroupPercentOccurrence_Text));
   %let trNone = %nrbquote(%LocaleGet(None_Text));
   %let trMissing = %nrbquote(%LocaleGet(Missing_Text));
      
   %if %length(&&in_&domain)=0 %then %do;
      %put [MS_S_0013];
      %put ERROR: The &domain or ad&domain data set does not exist for this study.;
      %let exiterror=1;
      %goto mexit;
   %end;
   
    %if %upcase(&TrtUse) = NONE %then %do;
       %let TrtName = ;
       %let TrtLabel = ;
    %end;

	
   %PrepOutDS(Distribution_OutData,Distribution_OutDataName,&StudyName,_&domain.d);

   /*kemicl add to attach domain to setting */
   %global OutName;
   %let OutName = &StudyName._&domain;
   %if &exiterror %then %goto mexit;   
   	
   %if %upcase(&CountMultiple)=NO %then %let doPercents = 1;
   %else %let doPercents = 0;
   
   /* Check for Crossover Periods */
   %let CODateVar = &domain.STDTC;   
   %if (%sysfunc(findw(&&&domain.VARS, %upcase(&CODateVar)))=0 or %upcase(&TrtUse)=NONE or %upcase(&domain)=MH or  %upcase(&TrtUse) =SPECIFIED BELOW) %then %let NTrtPeriods = 1;
   /* assign crossover treatments */
   %if &NTrtPeriods > 1 %then %do;
   	%let doPercents = 0;
      %AssignCOTreatment(&domain, &domain, &CODateVar);
   %end;
   %else %do;
      %let TrtVarList = ;
   %end;
   
	/* add trtvar to Byvar list */
	%if %length(&TrtName) %then %do;
		%if ^%index(&DesignByVars,&TrtName) %then %do;
			%let DesignByVars = &TrtName &DesignByVars;
		%end;
	%end;
	%if ^%symexist(SLDOSEVar) %then %let SLDOSEVar = 0;

   /* kemicl fill missing values of the Term Level and Group Level variables */
   %if %length(&fillmissingVars) %then %do;
   	%let i = 1;
      data &domain; 
         set &domain;
			%do %while (%length(%scan(&fillmissingVars,&i))>0);
				if %scan(&fillmissingVars,&i) = "" then %scan(&fillmissingVars,&i) = "&trMissing";
				%let i = %eval(&i+1);
			%end;
      run;
   %end;
   

   /* Compute Denominators for Percents from ADSL in work */
   %let adata = &in_adsl;
   %if &NtrtPeriods > 1 and &doTreatmentRRs = 0 %then %do;
		data adsl;
			set &in_adsl;
			length &TrtName $ &MaxTrtVarlen;
			label &TrtName = "Treatment";
			%do ii=1 %to &NTrtPeriods;
				Period = &ii;
				&TrtName = trim(left(%scan(&TrtVarList,&ii,' ')));
				if not missing(&TrtName) then output;
			%end;
		run;
      %let adata = adsl;
   %end;
   
   /* Check number of subjects in adsl */
   %nobsvars(&adata);
   %let nsubjects = &nobs;
   %put nsubjects = &nsubjects;
   %DMFlags;
   %if &exiterror %then %goto mexit;
   
   /* Check for more than one level of Study ID to see if combined studies  */
   %let StudyLevs = ;
   %let StudyList = ;
   %if %sysfunc(findw(%upcase(&ADSLvars), STUDYID)) %then %do;
      %GetLevels(&adata,STUDYID,StudyList,_LPrefix = NLGrp,_nLvls=StudyLevs,_vType= nLGType);
   %end;

   %let DMlist = ;
   %if %length(&TrtName) %then %let DMlist = &DMList &TrtName;
   %if &doSex and %upcase(SEX) ne %upcase(&TrtName) %then %let DMlist = &DMlist SEX;
   %if &doRace and %upcase(RACE) ne %upcase(&TrtName) %then %let DMlist = &DMlist RACE;
   %if &doCtry and %upcase(COUNTRY) ne %upcase(&TrtName) %then %let DMlist = &DMlist COUNTRY;
   %if &doSite and %upcase(SITEID) ne %upcase(&TrtName) %then %let DMlist = &DMlist SITEID;
   %if (&StudyLevs > 1 and %upcase(STUDYID) ne %upcase(&TrtName) and ^%index(%Upcase(&DesignByVars),STUDYID)) %then %let DMlist = &DMlist STUDYID;
   
   %if &NtrtPeriods > 1 %then %do;
   	%let DropList = %sysfunc(tranwrd(&DMList,&TrtName,%str()));
   %end;
   %else %do;
   	%let DropList = &DMList;
   %end;
   
   data dm_filter; 
	  set &adata;
	  keep USUBJID &TrtName %if &NtrtPeriods > 1 %then Period; &DMlist &DesignByVars;
   run;
   
   %if &doTreatmentRRs %then %do;
		proc sql noprint;
			create table dm_filter as select *,  1/freq(&TrtName) as p_&TrtName
			from dm_filter
			group by &TrtName
			order by usubjid;
		quit;
	%end;
  
   %if &NtrtPeriods > 1 %then %do;
      proc sort data= dm_filter;
         by &TrtName Period USUBJID ;
      run;
      
      proc sort data = &domain;
         by &TrtName Period USUBJID;
      run;
   %end;
   
	%let trsdosox = %nrbquote(%LocaleGet(StudyDayofStartofX_Text));
	%let trCount = %nrbquote(%LocaleGet(Count_Text));
	%let SeverityVar = %upcase(&domain)SEV;
	%let ToxGrVar = %upcase(&domain)TOXGR;
	%let trMild = %nrbquote(%LocaleGet(Mild_Text));
	%let trModerate = %nrbquote(%LocaleGet(Moderate_Text));
	%let trSevere = %nrbquote(%LocaleGet(Severe_Text));
	%let trLifeThreatening = %nrbquote(%LocaleGet(LifeThreatening_Text));
	%let trDeath = %nrbquote(%LocaleGet(Death_Text));
	%let SeriousVar = %upcase(&domain)SER;
	%let trN = %nrbquote(%LocaleGet(N_Text));
	%let trY = %nrbquote(%LocaleGet(Y_Text));

	data domdata;
		merge &domain(in=dmf)  dm_filter ;
		by  %if &NtrtPeriods > 1 %then &TrtName Period; USUBJID;
		_Count_ = 1;
		label _Count_ = "&trCount";
		%if %upcase(&domain) = SU %then %do;
			%let trlabel = %nrbquote(%LocaleFill(&trsdosox, %nrbquote(%LocaleGet(SubstanceAbuse_Text)))); 
			if missing(&domain.STDY) or missing(%upcase(&domain)DUR) then do;
				label &domain.STDY = "&trlabel";
			end;
		%end;
		%else %if %upcase(&domain) = MH %then %do;
			%let trlabel = %nrbquote(%LocaleFill(&trsdosox, %nrbquote(%LocaleGet(MedicalHistoryEvent_Text))));
			label &domain.STDY = "&trlabel";
		%end;       
		%else %if %upcase(&domain) = DS %then %do;
			%let trlabel = %nrbquote(%LocaleFill(&trsdosox, %nrbquote(%LocaleGet(DispositionEvent_Text))));
			if missing(&domain.STDY) or missing(%upcase(&domain)DUR) then do;
				label &domain.STDY = "&trlabel";
			end;
		%end;       
		%else %if %upcase(&domain) = CE %then %do;
			%let trlabel = %nrbquote(%LocaleFill(&trsdosox, %nrbquote(%LocaleGet(ClinicalEvent_Text))));
			if missing(&domain.STDY) or missing(%upcase(&domain)DUR) then do;
				label &domain.STDY = "&trlabel";
			end;
		%end;
		%else %if %upcase(&domain) = DV %then %do;
			%let trlabel = %nrbquote(%LocaleFill(&trsdosox, %nrbquote(%LocaleGet(ProtocolDeviation_Text))));
			if missing(&domain.STDY) or missing(%upcase(&domain)DUR) then do;
				label &domain.STDY = "&trlabel";
			end;
		%end;                
		%else %do;
			if missing(&TmName) then delete;
		%end;
		%if %sysfunc(findw(&&&domain.VARS, &SeriousVar)) %then %do;
			if upcase(&SeriousVar)="N" or kupcase(&SeriousVar) in (%unquote(%LocaleGetAll(N_Text, _case = u))) then SERIOUS = 1;
			else if upcase(&SeriousVar)="Y" or kupcase(&SeriousVar) in (%unquote(%LocaleGetAll(Y_Text, _case = u))) then SERIOUS = 2;
         else SERIOUS = 0;
		%end;
		%if %sysfunc(findw(&&&domain.VARS, &SeverityVar)) %then %do;
			if upcase(&SeverityVar)="MILD" or kupcase(&SeverityVar) in (%unquote(%LocaleGetAll(Mild_Text, _case = u))) then SEVERITY = 1;
			else if upcase(&SeverityVar)="MODERATE" or kupcase(&SeverityVar) in (%unquote(%LocaleGetAll(Moderate_Text, _case = u))) then SEVERITY = 2;
			else if upcase(&SeverityVar)="SEVERE" or kupcase(&SeverityVar) in (%unquote(%LocaleGetAll(Severe_Text, _case = u))) then SEVERITY = 3;
			else if upcase(&SeverityVar)="LIFE THREATENING" or kupcase(&SeverityVar) in (%unquote(%LocaleGetAll(LifeThreatening_Text, _case = u))) then SEVERITY = 4;
			else if upcase(&SeverityVar)="DEATH" or kupcase(&SeverityVar) in (%unquote(%LocaleGetAll(Death_Text, _case = u))) then SEVERITY = 5;
			else SEVERITY = 0;
	   %end;
		if dmf;
	run;;
   
   %nobsvars(domdata);
   %if &nobs=0 %then %do;
      %put [MS_S_0208];
      %put ERROR: The merge of the %upcase(&domain) and &in_adsl data sets resulted in 0 observations. Please check your data for accuracy.;
      %let exiterror=1;
      %goto mexit;
   %end;
   
   %let domainlabellist = ;
   %if %length(&stackVars) %then %do;
      %let i = 1;
      %do %while (%length(%scan(&stackVars,&i)));
         %let currvar = %scan(&stackVars,&i);
         %if %length(&currvar) %then %do;
            %let &currvar.Label = &currvar;
            %CheckLabel(domdata, &currvar.Label);
            %let domainlabellist = &domainLabelList &&currvar.Label;
         %end;
         %let i = %eval(&i+1);
      %end;
   %end;
   
   /* KELCI:  NEED TO HANDLE COUNTS OF EVENTS WITH THE SAME VALUE BUT DIFFERENT GROUP */
   /* create a first occurrence flag in the output data set based on sort date */
   /* kemicl account for crossover to count unique events per subject per period */
   %if %upcase(&CountMultiple)=NO %then %do;
      proc sort data=domdata out=domdata;
            by %if &UseGroups %then &TmGroup; &TmName  %if &NTrtPeriods > 1  %then PERIOD; USUBJID 
               %if  %sysfunc(findw(&&&domain.VARS, &SeriousVar)) %then %do; 
               	descending SERIOUS 
               %end; 
               %if %sysfunc(findw(&&&domain.VARS, &ToxGrVar)) %then %do; 
               	descending &ToxGrVar
               %end;                     
               %else %if %sysfunc(findw(&&&domain.VARS, &SeverityVar)) %then %do; 
               		descending SEVERITY
               %end;
               &domain.STDY;
      run;
      
      data domdata; set domdata;
         by %if &UseGroups %then &TmGroup; &TmName %if &NTrtPeriods > 1 %then PERIOD; USUBJID;
         if first.USUBJID then output;
      run;
   %end;
   
	/*create counts for barcharts, used to be treemaps*/
	/* create counts for ordering */
	/* kemicl written to generically hand making more count values but first value of list MUST be TmName */
	%let createcountvars = &countplotVars;
	%if %length(&TmGroup) %then %do;
		%let createcountvars = &countplotVars &TmGroup;
	%end;

	%if (^%symexist(TreatmentPropThresh) or %upcase(&TrtUse) = NONE) %then %let TreatmentPropThresh = 0;
	
	%let i = 1;
	%do %while(%length(%scan(&createcountvars,&i)));
		%let percentvar = %scan(&createcountvars,&i);

		proc sort data=domdata(keep= %if &UseGroups and &i = 1 %then &TmGroup; %if &TreatmentPropThresh > 0 and &i = 1 %then &TrtName; &percentvar) out=getcounts;
			%if &UseGroups and &i = 1 %then %do;
				by &TmGroup &percentvar;
			%end;
			%else %do;
				by &percentvar;
			%end;
		run;

  
   
		proc freq data=getcounts noprint;
			%if &UseGroups and &i = 1 %then %do;
				tables &TmGroup*&percentvar / out=countdt(drop = PERCENT);
			%end;
			%else %do;
				tables &percentvar / out=countdt(drop = PERCENT);
			%end;
			%if &TreatmentPropThresh > 0 and &i = 1 %then %do;
				tables &percentvar*&TrtName /  out = tgcountdt(rename = (Count = tgCount) drop =PERCENT );
			%end;
		run;

		%if %upcase(&CountMultiple)=NO and &i=1  %then %do;
			data countdt; set countdt;
				Percent = round((count/&nsubjects)*100,0.1);
				label Percent = "&polabel";
			run;
		%end;
		
		%if &TreatmentPropThresh > 0 and &i = 1 %then %do;
			proc freq data=&adata noprint;
				tables &TrtName / out=tgcnts(rename = (Count = TrtCount) drop =PERCENT );
				where not missing(&TrtName);
			run;

			proc sql ;
				create table tgcountdt as 
				select * from tgcountdt as d1 left join tgcnts as d2
				on d1.&TrtName = d2.&TrtName
				order by &percentvar;
			quit;

			data tgcountdt;
				set tgcountdt;
				TGPercent = round((tgcount/TrtCount)*100,0.1);
			run;
			proc transpose data=tgcountdt out = tgpcts Prefix=TGPct;
				by &percentvar;
				Var TGPercent;
			run;

			data tgpcts;
				set tgpcts;
				MaxPercent = max( of TGPct:);
				label MaxPercent = "&TGpolabel";
				keep &percentvar MaxPercent;
			run;
		%end;
		
		proc datasets;
			modify countdt;
			%if &i = 1 %then %do;
				label count = "&tclabel";
			%end;
			%else %do;
				rename count = group_count;
				label group_count = "&gclabel";
			%end;
		quit;

		proc sql;
			create table domdata as
			select * from domdata as d1 left join countdt as d2 
			on %if &UseGroups and &i = 1 %then d1.&TmGroup=d2.&TmGroup and; d1.&percentvar=d2.&percentvar
			%if &TreatmentPropThresh > 0 and &i = 1 %then %do;
				left join tgpcts as d3 on d1.&percentvar=d3.&percentvar
			%end;
			order by USUBJID;
		quit;
		%let i = %eval(&i+1);
	%end; 

	%let GroupVarLabel = ;
	%if %symexist(TmGroup) %then %do;
		%if %length(&TmGroup) %then %do;
			%let GroupVarLabel = &TmGroup;
			%CheckLabel(domdata, GroupVarLabel);
		%end;
	%end;
	%else %let TmGroup = ;
	
   %DMLabels(&adata);

   /* Treatment Incidence Filter, for now group across crossovers*/
   %if &doTreatmentRRs %then %do;
      proc sort data=domdata(keep = &TmName &TrtName p_&TrtName) out=ddsort;
         by &TmName &TrtName; 
      run;
      
      proc means data=ddsort;
         by &TmName &TrtName; 
         var p_&TrtName;
         output out=ddsums sum(p_&TrtName) = TrtIncidence;
      run;

		/*S1459060 kemicl to handle shorter names of treatments*/
		data getshorts;
			set fc;
			_shorttrt_ = cats(trim(substr(&TrtName,1,min(length(&TrtName),25))),_n_);
			call symput("stlev"||trim(left(_n_)),trim(left(_shorttrt_)));
			keep &TrtName _shorttrt_;
		run;
		
		proc sql noprint;
         create table ddsums as
         select * from ddsums a1 left join getshorts a2
         on a1.&TrtName=a2.&TrtName
         order by &TmName, &TrtName;
       quit;		
      
      proc transpose data = ddsums out=sumst(drop=_name_);
         by  &TmName;
         var TrtIncidence;
         id _shorttrt_;
         idlabel &TrtName;
      run;

      %sasname(%nrbquote(&&stlev&plev));
      %let sascontrollev = &sasname;
      %do i = 1 %to %eval(&nlev);
         %sasname(%nrbquote(&&stlev&i));
         %let sastrtlev&i = &sasname;
         %let rrlabel&i = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(RelativeRiskforX_Text)), f1 = %nrbquote(&&tlev&i)));
      %end;
      %let maxrrlabel = %nrbquote(%LocaleGet(MaxTreatmentRR_Text));
      %let trtocclabel = %nrbquote(%LocaleGet(TreatmentOnlyOccurrenceFlag_Text)); 
      
      data rrs(keep = &TmName RR: %if %eval(&nlev) > 2 %then MaxRRValue; TrtoccFl);
         set sumst;
         %do i = 1 %to %eval(&nlev);
            %if &i ^= &plev %then %do;
               RR_trtlev&i._over_control = round(&&sastrtlev&i/&sascontrollev,0.01);
               label RR_trtlev&i._over_control = &&rrlabel&i;
            %end;
         %end;
         %if %eval(&nlev) > 2 %then %do;
            MaxRRvalue = max(of rr:);
            label MaxRRvalue = &maxrrlabel;
         %end;
         if missing(&sascontrollev) then TrtOccFl = 1;
         else TrtOccFl = 0;
         label TrtOccFl= "Treatment Only Occurrence Flag";
      run;
      
      data domdata;
         set domdata;
         if 0 then set rrs;
         if _n_ = 1 then do;
            declare hash h(dataset:"rrs");
            h.defineKey("&TmName");
            h.defineData(ALL:"YES");
            h.defineDone();
         end;
         
         if h.find() = 0;
      run;
   %end; 
   
   %if ^%symexist(PropThresh) %then %let PropThresh = 0;
	%let Pwherestmt = %nrbquote();
	%if (&PropThresh > 0 and &TreatmentPropThresh > 0) %then %let Pwherestmt = %nrbquote(Percent >= &PropThresh and MaxPercent >= &TreatmentPropThresh);
	%else %if &PropThresh > 0 %then %let Pwherestmt = %nrbquote(Percent >= &PropThresh);
	%else %if &TreatmentPropThresh > 0 %then %let Pwherestmt = %nrbquote(MaxPercent >= &TreatmentPropThresh);
	/*create final output data */
	proc sort data= domdata %if &PropThresh > 0 or &TreatmentPropThresh > 0 %then (where = (%unquote(&Pwherestmt)));;
		by 	%if &NTrtPeriods > 1 %then Period; USUBJID;
	run;
	
   %nobsvars(domdata);
   	%if &nobs = 0 %then %do;
   		%put [MS_S_0376];
   		%put ERROR: There are no observations in the analysis data set after applying report filters and processing data.;
   		%let exiterror=1;
   		%goto mexit;
	%end;	
	
	%if &NtrtPeriods > 1 %then %do;
		proc sort data=dm_filter;
			by Period USUBJID;
		run;
	%end;
	
	%let Ntext = %nrbquote(%LocaleGet(N_Text));
	
	%if &doRates %then %do;
		data dm_filter;
			merge dm_filter patientDaysDT(in=a);
			by USUBJID;
			if a;
		run;
	%end;
	
	data &Distribution_OutData;
		merge domdata dm_filter;
		label N ="&NText";
		by 	%if &NTrtPeriods > 1 %then Period; USUBJID;
		if first.USUBJID then N = 1;
		%if &doRates %then %do;
			else PatientDays = .;
		%end;
	run;
	
	/* S1576842 kemicl add sort by Total Group and Term Counts for output for order by count  */
	%if %upcase(&TableSortOrder) = COUNT %then %do;	
		proc sort data= &Distribution_OutData;
			by %if %length(&TmGroup)%then descending group_count &TmGroup; descending count &TmName;
		run;
	%end;
	
	/* GET Variable Labels */
   %let SubjectLabel = USUBJID;
   %let DecodLabel = &TmName;
   %let StdyLabel = &domain.STDY;
   %CheckLabel(domdata,SubjectLabel);   
   %CheckLabel(domdata,StdyLabel);
   %CheckLabel(domdata,DecodLabel);
   %let doEPOCH = 0;
   %let doEPOCH =  %sysfunc(findw(&&&domain.VARS,EPOCH));
   %if &doEPOCH %then %do;
      %let EpochLabel = EPOCH;
      %CheckLabel(domdata,EpochLabel);
   %end;
   %if %length(&distributionVars) %then %do;
      %let i=1;
      %let f=1;
      %do %while(%length(%scan(&distributionVars,&i)));
         %let ev = %scan(&distributionVars,&i); 
         %let &ev.Label = %upcase(&ev);
         %let vnum = %sysfunc(findw(&&&domain.VARS,&&&ev.Label));
         %if &vnum > 0 %then %do;
            %CheckLabel(domdata,&ev.Label);  
            %let evl&f = &&&ev.Label;
            %let f=%eval(&f+1);
         %end;
         %let i=%eval(&i+1);
      %end;
      %let nev = %eval(&f-1);
   %end;    
   %else %let nev = 0;

      %if %length(&customFilterVars) %then %do;
         %put occurdomains = &occurrencebdsdomains;
         %put domain = &domain;
         %if %sysfunc(findw(upcase(&occurrencebdsdomains), %upcase(&Domain))) %then %do;
            %let _fromOccurlist= ASTDTM AENDTM ASTDT AENDT ASTDY AENDY ASEV AREL ATOXGR;
            %let _toOccurlist= xxSTDTC xxENDTC xxSTDTC xxENDTC xxSTDY xxENDY xxSEV xxREL xxTOXGR; 
            %let j = 1;
	    %do %while(%length(%scan(&_fromOccurlist,&j,' ')));
		%let tempf = %scan(&_fromOccurlist,&j,' ');
		%let tempt = %scan(&_toOccurlist,&j,' ');
		%if %sysfunc(findw(upcase(&customFilterVars), &tempf)) %then %do;                     
		   %CUTWORD(list = customFilterVars, word = &tempf);                      
		   %let customFilterVars = &customFilterVars %sysfunc(tranwrd(&tempt, xx, &Domain));             
		%end;                                              
		%let j = %eval(&j+1);      
	    %end;
	    %put Filter = &customFilterVars;
         %end;
      
      %let i=1;
      %let f=1;
      %do %while(%length(%scan(&customFilterVars,&i)));
         %let dfv = %scan(&customFilterVars,&i); 
         %let &dfv.Label = %upcase(&dfv);
         %let vnum = %sysfunc(findw(&&&domain.VARS,&&&dfv.Label));
         %if &vnum > 0 %then %do;
            %CheckLabel(domdata,&dfv.Label);  
            %let dfvl&f = &&&dfv.Label;
            %let f=%eval(&f+1);
         %end;
         %let i=%eval(&i+1);
      %end;
      %let ndfv = %eval(&f-1);
   %end;    
   %else %let ndfv = 0;

   *** Added 2 to label so TRTLABEL from CMTRT doesnt overwrite treatment label ***;
   %if %length(&countplotVars) %then %do;
      %let i=1;
      %let f=1;
      %do %while(%length(%scan(&countplotVars,&i)));
         %let tv = %scan(&countplotVars,&i);
         %let &tv.Label2 = %upcase(&tv);
         %let vnum = %sysfunc(findw(&&&domain.VARS,&&&tv.Label2));
         %if &vnum > 0 %then %do;
            %CheckLabel(domdata,&tv.Label2); 
            %let tvl&f = &&&tv.Label2;
            %let f=%eval(&f+1);
         %end;
         %let i=%eval(&i+1);
      %end;
      %let ntv = %eval(&f-1);
   %end;    
   %else %let ntv = 0;  

   %let odata = domdata;
   %include "&MacroPath./DesignByVars.sas";
   
   %if %upcase(&CountMultiple)=NO %then %let AxLab = %nrbquote(%LocaleGet(Subjects_Text));
   %else %let AxLab = %nrbquote(%LocaleGet(Occurrences_Text));
   
   /*Set up macros for cross drilldowns*/
   /*
   %if %upcase(&domain) = CM %then %do;
      %let APddname = AEDistribution;
      %let crossdomain = AE;
   %end;
   %else %if %upcase(&domain) = AE %then %do;
      %let APddname = InterventionsDistribution;
      %let crossdomain = CM;
   %end;
   */
   
   * create JSL file;
   %PrepOutFile(DistributionScript,DistributionScriptName,&StudyName &ProcessName Script for &domain..jsl);
   %global _mainjslfile_ FullAPName;
   %let _mainjslfile_ = &DistributionScript;
   %let FullAPName=%str(%upcase(&domain) Distribution);
   
   %let DeltaLabel = ;  
   * For previous added study, there is no global variable for ReviewsEnabled; 
   %if ^%symexist(ReviewsEnabled) %then %do;
      %global ReviewsEnabled;
      %let ReviewsEnabled=1;
   %end;
   %if &ReviewsEnabled  and &ReviewNumber %then %do;
      %let DeltaLabel = &domain.RFlg;
      %CheckLabel(domdata,DeltaLabel);
   %end;
   
   %if &StudyLevs > 1 %then %do;
      %put Data contains records from &StudyLevs Studies;
      %let StudyLabel = STUDYID;
      %CheckLabel(&adata, StudyLabel);
   %end;
   
   %let FormulaVar = ;
   %let trShowButtonTitle = ;
   %let trTextBoxContentsPR = ;
   %if ^%symexist(RateMultiplier) %then %let RateMultiplier = 1;
   %if ^%symexist(MissingPatients) %then %let MissingPatients = 0;
   %if &doPercents %then %do;
   	%let RateMultiplier = 1;
   	%let FormulaVar = %nrbquote(%  );
   	%let trShowButtonTitle = %nrbquote(%LocaleGet(ShowPercents_Text));
   	%let trPercentRateTitle = %nrbquote(%LocaleGet(PercentOccurrenceinDemographicGroup_Text));
   	%let trTextBoxContentsPR = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(DispValsIndPercSubjWithinDemGrpExpAnX_Text)),f1 = %nrbquote(&textlabel)));
   %end;
  	%else %if &doRates %then %do;
  		%let FormulaVar =  %nrbquote(%LocaleFill( %nrbquote(%LocaleGet(IRPerXPY_Text)), f1 = %nrbquote(&RateMultiplier)));
  		%let trOverallIR =  %nrbquote(%LocaleGet(OverallIncidenceRate_Text));
  		%let trShowButtonTitle = %nrbquote(%LocaleGet(ShowIncidenceRates_Text));
   	%let trPercentRateTitle =  %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(IncidenceRatePerXPatientYears_Text)), f1 = %nrbquote(&RateMultiplier)));	
   	%if %upcase(&RateType) = %nrbquote(PYE) %then %do;
   		%let trTextBoxContentsPR = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(DispValsIndRatePerXPatientYearsXofAnEvent_Text)),f1 = %nrbquote(&RateMultiplier), f2 = %nrbquote(%localeGet(PatientYearsofExposure_Text))));
   		%let trTextBoxTabulateRates = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(IRRepresentXPatientYearsofX_Text)),f1 = %nrbquote(&RateMultiplier), f2 = %nrbquote(%localeGet(PatientYearsofExposure_Text))));  		
  		%end;
  		%else %do;
   		%let trTextBoxContentsPR = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(DispValsIndRatePerXPatientYearsXofAnEvent_Text)),f1 = %nrbquote(&RateMultiplier), f2 = %nrbquote(%localeGet(PatientYearsonStudy_Text))));  	
   		%let trTextBoxTabulateRates = %nrbquote(%LocaleFill(%nrbquote(%LocaleGet(IRRepresentXPatientYearsofX_Text)),f1 = %nrbquote(&RateMultiplier), f2 = %nrbquote(%localeGet(PatientYearsonStudy_Text))));  		   		
  		%end; 
  	%end;

  	
	%let trTotal = %nrbquote(%LocaleGet(Total_Text));
   * put JSL statements;
   data _null_;
      file "&DistributionScript" %if %nrbquote(&SYSENCODING) ne wlatin1 %then encoding="utf-8";;
      put "//!";
      put "Names Default to Here(1);";
      put "objRefNS = newNamespace();";
      put "jg:currentObjRefNamespaceName = objRefNS << getName;";
      put "objRefNS:DataList = {};";
      put "objRefNS:DataNameList = {};";
      put "objRefNS:TabButtonList = {};";
      put "objRefNS:TabCodeList = {};";
      put "objRefNS:TabAfterCodeList = {};";
      put "objRefNS:TabOpenList = {};";
      put "objRefNS:CreateReportList = {};";
      put "objRefNS:ShowCreateLiveReport = 1;";      
      put "objRefNS:CreateLiveReportList = {};";
      put "objRefNS:TMView = 0;";
      put "objRefNS:PercentRateShow = 0;";
      put "objRefNS:NoteDomain = ""%upcase(&domain)"";";
 
      /* Try to Delete Domain Distribution Filter */
      %if %symexist(SFname) %then %do;
         %if %upcase(&SFname) = DISTRIBUTION_DRILL_DOWN %then %do;
            put "Include(""$CLINICAL_HOME\JSLFiles\SubjectFilterUtilityFunctions.jsl"");"; 
            put "try(DeleteSubjectFilterByName(""Distribution Drill Down"", empty(), ""&studyname""));";
         %end;
      %end;

      put "OutPath= ""&OutPath"";";
      put "ClientOutPath=""&ClientOutPath"";";
      put "outFolder = ""&ClientOutPath"";";
      
      put "objRefNS:DtExpr  = Expr(";
      put "objRefNS:dbv = {};";
   	  %let DBVlabels = ;
      %do i=1 %to &ndbv;
         %if %quote(&&dbv&i) ne %quote(&TrtLabel) %then %do;
            put "InsertInto(objRefNS:dbv,Column(""&&dbv&i""));";
            %let DBVlabels = &DBVlabels %quote(,:Name(""&&dbv&i""));
         %end;
      %end;  
      put "   If(IsEmpty(objRefNS:dmd),";
		put "     objRefNS:dmd=open(""&ClientOutPath.&Distribution_OutDataName..sas7bdat"",invisible);"; 
      put "     reportRefNS:linkAnalysisTableToADSLTable(objRefNS:dmd);"; 
		put "   Current Data Table(objRefNS:dmd);"; 
      put "      if (reportRefNS:reviewReplayIncludeDataPreprocessing,";
      put "      	  jg:ApplyValueOrderToTables(EvalList({objRefNS:dmd}), ""&StudyName"");";  
      %if %upcase(&TableSortOrder) = COUNT %then %do;	
		  put "			  Column(""&DecodLabel"")<< Set Property(""Row Order Levels"", (1));";
		  %if %length(&GroupVarLabel) %then %do;
		   put "    Column(""&GroupVarLabel"") << Set Property(""Row Order Levels"", (1));";
		  %end;
	  %end;
      put "          objRefNS:dmd << New Column(locale:get(""None_Text""), Character, Nominal, << Hide(1),";
      put "                           << Set Values(Repeat({""."" /*locale:get(""DemographicGrouping_Text"") || "": "" || locale:get(""None_Text"")*/}, NRows(objRefNS:dmd))));";
      put "          objRefNS:dmd << New Column(locale:get(""None_Text"") || ""_"", Character, Nominal, << Hide(1),";
      put "                           << Set Values(Repeat({""."" /*locale:fill(locale:get(""XStacking_Text""), {""&&DOMAINLABEL_&domain""}) || "": "" || locale:get(""None_Text"") || ""_""*/}, NRows(objRefNS:dmd))));";
      %if &doPercents %then %do;
			put "       objRefNS:dmd << New Column(""_Denominator_"",";
			%if %length(&TrtLabel) %then %do;
				put "       set Formula(ColSum(:Name(""&NText""), :Name(""&TrtLabel"") &DBVlabels, Excluded()))";
			%end;
			%else %do;
				put "       set Formula(ColSum(:Name(""&NText"") &DBVlabels, Excluded()))";
			%end;
			put "       );";
     		put "      objRefNS:dmd << New Column(""&FormulaVar"",set Formula(&RateMultiplier/:Name(""_Denominator_"")));";  	
      		put "		  objRefNS:dmd << New Column(""_GrpN_"",""Character"",set Formula(""(N = "" || Char( :_Denominator_ ) || "")""));"; 
      		put "		  Column(objRefNS:dmd,""&poLabel"")<<Set Formula(If( !IsMissing(:&trCount),Round(100*(ColSum(:&trCount,:Name(""&DecodLabel""),Excluded())/(ColSum(:Name(""&NText""),Excluded()))),1),.));";
		%end;
		%else %if &doRates %then %do;
			put "       objRefNS:dmd << New Column(""_Denominator_"",";
			%if %length(&TrtLabel) %then %do;
				put "       set Formula(ColSum(:Name(""PatientDays""), :Name(""&TrtLabel"") &DBVlabels, Excluded())/365.25)";
			%end;
			%else %do;
				put "       set Formula(ColSum(:Name(""PatientDays"") &DBVlabels, Excluded())/365.25)";
			%end;
			put "       );";
     		put "      objRefNS:dmd << New Column(""&FormulaVar"",set Formula(&RateMultiplier/:Name(""_Denominator_"")));";
     		put "		  Column(objRefNS:dmd,""&FormulaVar"")<<Format( ""Fixed Dec"",10, 1 );";    
     		put "		   objRefNS:dmd <<New Column(""&trOverallIR"",set Formula((ColSum(:&trCount,:Name(""&DecodLabel""), Excluded())*&RateMultiplier)/(ColSum(:Name(""PatientDays""),Excluded())/365.25)));";
     		put "		  Column(objRefNS:dmd,""&trOverallIR"")<<Format( ""Fixed Dec"",10, 1 );";    
      	put "		  objRefNS:dmd << New Column(""_GrpN_"",""Character"",set Formula(""(PY = "" || Char( Round(:_Denominator_,2)) || "")""));";    		
     		
		%end;		
      put "         Column(objRefNS:dmd,""&SubjectLabel"") << Label(1);";  
      %if %length(&StdyLabel) %then %do;
         put "       Try(Column(objRefNS:dmd,""&StdyLabel"") << Set Modeling Type( Continuous));";
      %end; 
      /*%if %length(&GroupVarLabel) %then %do;
         put "    objRefNS:dmd << Color by Column(:Name(""&GroupVarLabel""), Color Theme( ""JMP Light"" ));";
         put "    vcoloraa = Associative Array();";
         put "    For Each Row( vcoloraa[Column(""&GroupVarLabel"")[Row()]] = Color Of( Row State( Row())));";
         put "    vcolors = vcoloraa << Get Values;";
         put "    For(";
         put "       v = 1;";
         put "       vc = vcoloraa <<first;, !IsEmpty(vc), vc = vcoloraa <<next(vc);";
         put "       v++;,";
         put "       vcolors[v] = Substitute(Expr(_label_ = _color_), Expr( _label_ ), vc, Expr( _color_ ), vcoloraa[vc])";
         put "    );";
         put "    Column(""&GroupVarLabel"") << Set Property( ""Value Colors"", vcolors);";
      %end;*/
      %if &doTreatmentRRs %then %do;
         put "    Try(Column(objRefNS:dmd,""&trtocclabel"") << Set Modeling Type(Nominal));";
      %end;     
      put "		,";  /* else for reviewReplayInclude */
		%if &doPercents %then %do;
		   %if %length(&TrtLabel) %then %do;
				put "      Column(objRefNS:dmd,""_Denominator_"")<<set Formula(ColSum(:Name(""&NText""),:Name(""&TrtLabel"") &DBVlabels, Excluded()));";	
			%end;
			%else %do;
				put "       Column(objRefNS:dmd,""_Denominator_"")<<set Formula(ColSum(:Name(""&NText"") &DBVlabels,Excluded()));";	
			%end; 
		%end;
		%else %if &doRates %then %do;	
		   %if %length(&TrtLabel) %then %do;
				put "      Column(objRefNS:dmd,""_Denominator_"")<<set Formula(ColSum(:Name(""PatientDays""),:Name(""&TrtLabel"") &DBVlabels, Excluded())/365.25);";	
			%end;
			%else %do;
				put "       Column(objRefNS:dmd,""_Denominator_"")<<set Formula(ColSum(:Name(""PatientDays"") &DBVlabels, Excluded())/365.25);";	
			%end; 
		%end;		
      put "       ); //End of check for reportRefNS:reviewReplayIncludeDataPreprocessing";
      put "  ,";  /*else for isempty*/;
      put "    Current Data Table(objRefNS:dmd);";
      put "  );";
      put ");";
      /* run/open data table now before results function calls */
      put "objRefNS:DtExpr;"; 
      
      %macro barplot1(ii,groupx1,overx2);
         put "    VListBox(";
         put "    objRefNS:gb&ii = objRefNS:dmd<<Graph Builder(";
         put "       Size(675,625),";
         put "       Show Control Panel(0), Show Legend(1), Auto Stretching(0),";
         put "       Variables(";
         %if &UseGroups %then %do;
         	put "			X( :Name(""&GroupVarLabel""), Order By(:Name(""&gclabel""), Descending)),";
         %end;
         put "          X( :Name(""&&tvl&ii"")";
         put "             ,Position(1)";
         put "            ,Order By(:Name(""&tclabel""), Descending)";
         put "          )";
         %do b=2 %to &ndbv;
            put "    , Group X( :Name(""&&dbv&b"") )";
         %end;
         %if %length(&groupx1) %then %do;
            put "    ,Group Y( Column(&groupx1) )";
         %end;       
         %if %length(&overx2) %then %do;
               put "    , Overlay(Column(&overx2))";
         %end;
         put "       ),";
         put "       Elements( Bar( ";
         %if &UseGroups %then %do;
         	put "			X(2),X(1), ";
         %end;
         %else %do;
         	put "			X, ";
		 %end;
         %if ^%symexist(DOMAINLABEL_&domain) %then %let DOMAINLABEL_&domain = %nrbquote(&domain);
         put "			Legend( 2 ), Bar Style( ""Stacked"" ), Summary Statistic( ""Sum"" ) ))";
         put "          ,SendToReport(";
         put "             Dispatch( {}, ""graph title"", TextEditBox, {Set Text( "" "" )} ),"; 
         put "             Dispatch( {}, ""Graph Builder"", OutlineBox, {Set Title( locale:fill(locale:get(""XCountsGraph_Text""),";
         put " {""&&DOMAINLABEL_&domain""}) )} )";   
         put "          )";
         put "    )),";
      %mend;
 
       
 		put "objRefNS:findVarByRole= function({varlist, rolename}, {i},";
       put "	 for (i = 1, i <= n items(varlist), i++,"; 
       put "       if (varlist[i][""Role""] == rolename, Return(i));"; 
       put " );"; 
       put " 0;     // not found";
		put ");";  
		
		%macro tabulate1(ii,gpcols,addTabNum);
			put " 	gExpr = expr(expr());";			
			%if %length(&gpcols) %then %do;
				put "  if (nItems(&gpcols),";	
				put " 	gExpr = expr(evalexpr(Column Table(Grouping Columns( expr(&gpcols)) ) ));";
				put " );";
			%end;
			put "    Eval(Eval Expr(objRefNS:tbhlb&ii = HListBox(";
			put "    objRefNS:tb1_&addTabNum._&ii = objRefNS:dmd<<Tabulate(Show Control Panel( 0 ),";
			%if &doPercents or &doRates %then %do;
				put "       Remove Column Label( Grouping Columns( :Name(""_GrpN_"")) ),";			
			%end;
			put "       Change Item Label( Statistics( N, ""&trTotal"" ) ";
			%if &doPercents or &doRates %then %do;
				put "       ,Statistics( Sum, ""  "" )";
			%end;
			put "       ),";
			%if &doPercents %then %do;
				put "       Set Format( Sum(:Name(""&FormulaVar"")(9,1,Percent))),";
			%end;
			%if %length(&GroupVarLabel) %then %do;
				put "       Add Table( Row Table( Grouping Columns( :Name(""&GroupVarLabel""),:Name(""&&tvl&ii"") )),";
			%end;
			%else %do;
				put "       Add Table( Row Table( Grouping Columns( :Name(""&&tvl&ii"") )),";
			%end;          	
			%if &doPercents or &doRates %then %do;
				put "       Column Table( Grouping Columns( &gpcols ) ";
				put "          ,Statistics( Sum ),";
				put "          Analysis Columns( :&trCount, :Name(""&FormulaVar""))";
				put "       )";				
			%end;
			%else %do;
				put " expr(gExpr)";
			%end;
			put "       ,Column Table(Statistics(N)),";
			put "    ),";  /* close Add Table */
			%if %length(&GroupVarLabel) %then %do;
				put "    Display Column Width( Row Label(""&GroupVarLabel""), 270),";
			%end;
			put "       Display Column Width( Row Label(""&&tvl&ii""), 255)";
			put " ),";  /* close tabulate */
			put " ),"; /* close Hlistbox */
			put " ));";
		%mend;
      
      put "objRefNS:ddw=Function({},{default local},";
      put " objRefNS:DtExpr;";
      %if (&ntv) %then %do;
			put "objRefNS:CSlist = {};";
			%if &doSite %then %do;
				put "InsertInto(objRefNS:CSlist,Column(""&SiteLabel""));";
			%end;
			%if &doCtry %then %do;
				put "InsertInto(objRefNS:CSlist,Column(""&CtryLabel""));";
			%end;
			%if &doSex %then %do;
				put "InsertInto(objRefNS:CSlist,Column(""&SexLabel""));";
			%end;
			%if &doRace %then %do;
				put "InsertInto(objRefNS:CSlist,Column(""&RaceLabel""));";
			%end;

			%do i=1 %to &ndbv;
				%if %quote(&&dbv&i) ne %quote(&TrtLabel) %then %do;
					put "InsertInto(objRefNS:CSlist,Column(""&&dbv&i""));";
				%end;
			%end;      
         put "       objRefNS:tmlist={";
         put "          ""&trNone"" ";       
         %if %length(&TrtLabel) %then %do;
            put "       ,""&TrtLabel"" ";
         %end;
         %if &doSex %then %do;
            put "       , ""&SexLabel"" ";
         %end;
         %if &doRace %then %do;
            put "       , ""&RaceLabel"" ";
         %end;                   
         %if &doCtry %then %do;
            put "       , ""&CtryLabel"" ";
         %end;    
         %if &doSite %then %do;
            put "       , ""&SiteLabel"" ";
         %end;
         %if ^%index(%Upcase(&DesignByVars),STUDYID) and &StudyLevs > 1 %then %do;
            put "       , ""&StudyLabel"" ";
         %end;
         put "       };";        
         
         put "       objRefNS:tm2list={";
         put "          ""&trNone"" ";
         %if &NtrtPeriods > 1 %then %do;
            put "       ,  ""Period"" ";
         %end;
         /* kemicl Process any stackvars present to put int widget*/
			%let j = 1;
			%do %while (%length(%scan(&domainLabelList,&j)));
				%let curravar = &%scan(&domainLabelList,&j);
				put "       ,""&curravar"" ";
				%let j = %eval(&j+1);
			%end;
         %if %upcase(&domain) = EX %then %do;
            %if &SLDOSEVar %then %do;
               put "    , ""&DoseLabel"" ";
            %end;
            %if &SLCATVar %then %do;
               put "    ,  ""&CatLabel"" ";
            %end;
         %end;
         %if &doEPOCH %then %do;
            put "       , ""&EPOCHLabel"" ";
         %end; 
         %if %length(&DeltaLabel) %then %do;
            put "          , ""&DeltaLabel"" ";
         %end;
         put "       };";
         /*
         put "   for(t=2,t<=NItems(objRefNS:tmlist),t++,";
         put "      cts = (CurrentDataTable() << Summary(Group(:(objRefNS:tmlist[t])), N)) << Sort(By(Column(3)),Order(Descending),Replace Table);";
         put "      valueorder = Column(objRefNS:tmlist[t])<<GetAsMatrix;";
         put "      Close(cts,nosave);";
         put "     :(objRefNS:tmlist[t]) << Set Property(""Value Ordering"",valueorder);";
         put "   );";  
         */
         /*Drew added the extra call to DtExpr to force reset of current data table*/
         put "   objRefNS:DtExpr;";
         put "    objRefNS:GBPexpr = expr(";
         %do i = 1 %to &ntv;        
            put "          objRefNS:gbr&i = report(objRefNS:gb&i)[Graph Builder Box(1)];";
            put "          objRefNS:gbr&i << Add Variable({:Name(""&FormulaVar""), Role(""Y"")});";
            put "          objRefNS:gb&i << SendToReport(";
            put "             Dispatch( {}, ""graph title"", TextEditBox, {Set Text( "" "" )} ),";
            put "             Dispatch({},""Y title"", TextEditBox,";
            put "                {Rotate Text(""Left""), Set Text(""&trPercentRateTitle"")}";
            put "          ));";
           	%if &doPercents %then %do;
            	put "          report(objRefNS:gb&i)[AxisBox(2)]<<format(""Percent"",9,0);";
            %end;
         %end;
         put "    );";
         
         put "  objRefNS:GBCexpr = expr(";
         %do i = 1 %to &ntv;
            put "          objRefNS:gb&i << SendToReport(";
            put "             Dispatch( {}, ""graph title"", TextEditBox, {Set Text( "" "" )} ),";
            put "             Dispatch({},""Y title"", TextEditBox,";
            %if %upcase(&CountMultiple)=YES %then %do;
               put "                {Rotate Text(""Left""), Set Text(locale:get(""Count_Text""))}";
            %end;
            %else %do;
               put "                {Rotate Text(""Left""), Set Text(locale:get(""SubjectCount_Text""))}";
            %end;
            put "          ));";
         %end;
         put "    );";
                  
      %end;
      
      put " VListBox(";   
                %if %length(&COFlag) %then %do;
                  put "objRefNS:COText1 = TextBox(locale:get(""MultTrtPeriodsHaveBeenDetectedandDisplayed_Text""), <<Set Wrap(850),<<Set Font Size(9), <<Bullet Point(1)),";
                  put "objRefNS:COText2 = TextBox(locale:get(""PreTrtHasBeenAssignedtoPeriodZero_Text""), <<Set Wrap(850),<<Set Font Size(9), <<Bullet Point(1)),";
         	%end;
		%if %length(&TEAEText) %then %do;
			put "objRefNS:TEAEText = TextBox(""&TEAEText"", <<Set Wrap(850),<<Set Font Size(9), <<Bullet Point(1)),";
		%end;                           
		put "    HListBox(";
		%if %upcase(&CountMultiple)=NO %then %do;
			%if %length(&COFlag) %then %do;
				put "   objRefNS:CPTB = TextBox(locale:fill(locale:get(""DisplayedCountsIndNumSubjExperAnXInEachPeriod_Text""),{""&textlabel""}), <<Set Wrap(650),<<Set Font Size(9), <<Bullet Point(1)),";
			%end;
			%else %do;
				put "   objRefNS:CPTB = TextBox(locale:fill(locale:get(""DisplayedCountsIndicateNumSubjExperiencingAnX_Text""),{""&textlabel""}), <<Set Wrap(650),<<Set Font Size(9), <<Bullet Point(1)),";
			%end;			
		%end;
		%else %do;
			put "   objRefNS:CPTB = TextBox(locale:fill(locale:get(""DisplayedCountsIndicateTotalNumOccOfAnX_Text""),{""&textlabel""}), <<Set Wrap(650),<<Set Font Size(9), <<Bullet Point(1)),";
		%end;
		%if &doPercents or &doRates %then %do;
			put "       TextBox(""  ""),";
			put "       objRefNS:pcbb = ButtonBox(""&trShowButtonTitle"",<<UnderlineStyle(1),";
			put "       <<Set Function(Function({this},";
			put "          objRefNS:CurrBName = this << Get Button Name();";
			put "          If(objRefNS:CurrBName == ""&trShowButtonTitle"",";
			put "             objRefNS:GBPexpr;";
			put "             objRefNS:PercentRateShow = 1;";
			put "             objRefNS:CPTB<< Set Text(""&trTextBoxContentsPR"");"; 
			put "             this << setButtonName(locale:get(""ShowCounts_Text""));";
			put "             ,";
			%do i = 1 %to &ntv;
				put "          objRefNS:gbr&i = report(objRefNS:gb&i)[Graph Builder Box(1)];";
				put "          objRefNS:gb&i << SendToReport(";
				put "             //Dispatch({},""Graph Builder"",OutlineBox,{Set Title( locale:fill(locale:get(""XCountsGraph_Text""),{""%upcase(&domain)""}) )}),";          
				put "             Dispatch( {}, ""graph title"", TextEditBox, {Set Text( "" "" )} ),"; 
				put "             Dispatch({},""Y title"", TextEditBox,";
				put "                {Set Text("" "")}";
				put "          ));";
				put "          objRefNS:gbr&i << Remove Variable({:Name(""&FormulaVar""), Role(""Y"")});";
			%end; 
			put "             objRefNS:PercentRateShow = 0;";
			put "             objRefNS:GBCexpr;";
			%if &doPercents %then %do;
				put "             objRefNS:CPTB << Set Text(locale:fill(locale:get(""DisplayedCountsIndicateNumSubjExperiencingAnX_Text""),{""&textlabel""}));";
			%end;
			%else %do;
				put "             objRefNS:CPTB << Set Text(locale:fill(locale:get(""DisplayedCountsIndicateTotalNumOccOfAnX_Text""),{""&textlabel""}));";		
			%end;
			put "             this << setButtonName(""&trShowButtonTitle"")";
			put "       ))));";
		%end;
		put "    ),"; 
		%if &MissingPatients %then %do;
			%if ^%symexist(SupportOngoing) %then %let SupportOngoing = NO;
			%if %upcase(&SupportOngoing) ^= YES %then %do;
				put "objRefNS:MissTextNote = TextBox(locale:fill(locale:get(""NoteXSubjectshadMissingDatesRecordsRemovedForRates_Text""),{""&MissingPatients""}), <<Set Wrap(725),<<Set Font Size(9), <<Bullet Point(1)),";
			%end;
			%else %do;
				put "objRefNS:MissTextNote = TextBox(locale:fill(locale:get(""NoteXSubjectshadMissingStDatesRecordsRemovedForRates_Text""),{""&MissingPatients""}), <<Set Wrap(725),<<Set Font Size(9), <<Bullet Point(1)),";
			%end;
		%end;
      put "      objRefNS:gbthlb = Vlistbox(";
      /* Draw distributions displays initially */
		%do i=1 %to &ntv;
			%if %symexist(dbv1) %then %do;
				%if &NtrtPeriods > 1 %then %do;
					%barplot1(&i,%quote(""&dbv1""),%quote(""Period""));
				%end;
				%else %do;
					%barplot1(&i,%quote(""&dbv1""),%str());
				%end;    
			%end;
			%else %do;
				%barplot1(&i,%str(),%str());
			%end;
		%end;
		%if &ntv %then %do;
			put " objRefNS:GBCexpr; ";
		%end;
      %else %do;
         put "      objRefNS:dd = objRefNS:dmd<<Distribution(";
         put "            Arrange in Rows(3),";
         put "            Automatic Recalc( 1 ),";
         %if %upcase(&SplitResults)=YES %then %do;
            put "         By(eval(objRefNS:dbv)),";
         %end;
         %if %index(&countplotVars,&TmName)=0 %then %do;
            put "         Nominal Distribution(Column(:Name(""&DecodLabel"")), ShowCounts(1),Order By( ""Count Ascending"" )),";
         %end;
         %do i=1 %to &nev;
            put "         Nominal Distribution(Column(:Name(""&&evl&i"")), ShowCounts(1)),";
         %end;       
         %if%length(&StdyLabel) %then %do;
            put "         Continuous Distribution(Column(:Name(""&StdyLabel"")), ShowCounts(0), Quantiles(0),Summary Statistics(0)),";
         %end;          
         put "         SendToReport(";
         %if %length(&StdyLabel) %then %do;
            put " //            Dispatch( {""&StdyLabel""}, ""Distrib Histogram"", FrameBox, {Frame Size(85, 275)} ),";
         %end; 
         %if %index(&countplotVars,&TmName)=0 %then %do;
            put "            Dispatch( {""&DecodLabel""}, ""Frequencies"", OutlineBox, Close( 1 ) ),";
         %end;
         %do i=1 %to &nev;
               put "            Dispatch( {""&&evl&i""}, ""Frequencies"", OutlineBox, Close( 1 ) ),";
         %end;

         put "         )";
         put "      ),";
      %end;
      put "     ),";
      put " );  //end listboxes"; 
      put ");";  /* End function for count plot content */
      
      /* Expression for Tabbed report to insert data filter into LHP */
         put "objRefNS:AddDataFilterContextBox = 1;";
         put "objRefNS:filterColumnsList = {};";
         %if %length(&DeltaLabel) %then %do;
            put "insertInto(objRefNS:filterColumnsList, {{""&DeltaLabel"", {}}});";
         %end;
         %if ^%index(%Upcase(&DesignByVars),STUDYID) and &StudyLevs > 1 %then %do;
            put "insertInto(objRefNS:filterColumnsList, {{""&StudyLabel"", {}}});";
         %end;         
         %if &doPercents %then %do;
            put "insertInto(objRefNS:filterColumnsList, {{""&tclabel"", {}}});";
            put "insertInto(objRefNS:filterColumnsList, {{""&polabel"", {}}});";
         %end;
         %else %if &doRates %then %do;
         	put "insertInto(objRefNS:filterColumnsList, {{""&trOverallIR"", {}}});";
         %end;
         %if &doTreatmentRRs %then %do;
            %if %eval(&nlev) > 2 %then %do;
               put "insertInto(objRefNS:filterColumnsList, {{""&maxrrlabel"", {}}});";
            %end;
            %else %do;
               %do i = 1 %to %eval(&nlev);
                  %if &i ^= &plev %then %do;
                     put "insertInto(objRefNS:filterColumnsList, {{""&&rrlabel&i"", {}}});";
               %end;
               %end;
            %end;
            put "insertInto(objRefNS:filterColumnsList, {{""&trtocclabel"", {}}});";
         %end;
         %if %length(&customFilterVars) %then %do;
			 %do i=1 %to &ndfv;
				put "insertInto(objRefNS:filterColumnsList, {{""&&dfvl&i"", {}}});";
			 %end;
	     %end;
	     %else %do;
			 %do i=1 %to &nev;
				put "insertInto(objRefNS:filterColumnsList, {{""&&evl&i"", {}}});";
			 %end;
	     %end;	     
      put "objRefNS:ReportDataFilterReferenceList = reportRefNS:createReportFilter(objRefNS:dmd, objRefNS:filterColumnsList);";
      
      %if &ntv %then %do; 
         put "objRefNS:AddLeftControlPanel = 1;";
         put "objRefNS:ddwa = Function({},{default local},";
         put "   objRefNS:LeftControlVBox << Append(";
         put "    VListBox(OutlineBox(locale:get(""View_Text""),";
         put "     Outlinebox(locale:get(""DemographicGrouping_Text""),";
         put "     objRefNS:glb=ListBox(objRefNS:tmlist,";
         %if %Upcase(&TrtUse) ne NONE %then %do;
            put "       maxselected(1),nlines(nitems(objRefNS:tmlist)),<<setselected(2,1)";
         %end;
         %else %do;
            put "       maxselected(1),nlines(nitems(objRefNS:tmlist)),<<setselected(1,1)";
         %end;
         put "   )),";
         %if ^%symexist(DOMAINLABEL_&domain) %then %let DOMAINLABEL_&domain = %nrbquote(&domain);
         put "   OutlineBox(locale:fill(locale:get(""XStacking_Text""), {""&&DOMAINLABEL_&domain""}),";
         put "    objRefNS:glb2 = ListBox(objRefNS:tm2list,";
         %if &NTrtPeriods > 1 %then %do;
            put "       maxselected(1),nlines(nitems(objRefNS:tm2list)),<<setselected(2,1)";
         %end;
         %else %do;
            put "       maxselected(1),nlines(nitems(objRefNS:tm2list)),<<setselected(1,1)";
         %end;
         put "   )))";
         put "  ));";      
         /* kemicl - script for column switcher box */            
         put " objRefNS:glb << Set Script(";
         put "    SelectOK = 1;";
         put "    try((objRefNS:glb<<GetSelected)[1],SelectOK = 0);";
         put "    If(SelectOK,";
         put "   objRefNS:DtExpr;";
         put "   SVar = (objRefNS:glb<<GetSelected)[1];";
         put "   SVar2 = (objRefNS:glb2<<GetSelected)[1];";
            /* Kemicl - update the formula for percent column to use right denominator */ 
         %if &doPercents or &doRates %then %do;
				put "		if(SVar == ""None"",";
				%if &doPercents %then %do;
					put "       Column(objRefNS:dmd,""_Denominator_"")<<set Formula(ColSum(:Name(""&NText"") &DBVlabels, Excluded()));";
				%end;
				%else %if &doRates %then %do;
					put "       Column(objRefNS:dmd,""_Denominator_"")<<set Formula(ColSum(:Name(""PatientDays"") &DBVlabels, Excluded())/365.25);";
				%end;				
				put "		,";
				%if &doPercents %then %do;
					put "   	   Eval(parse(EvalInsert(""\[Column(objRefNS:dmd, ""_Denominator_"")<<Set Formula(ColSum(:Name(""&NText""), :^Svar^ &DBVlabels, Excluded()))]\"")));";         
				%end;
				%else %if &doRates %then %do;
					put "   	   Eval(parse(EvalInsert(""\[Column(objRefNS:dmd, ""_Denominator_"")<<Set Formula(ColSum(:Name(""PatientDays""), :^Svar^ &DBVlabels, Excluded())/365.25)]\"")));";         				
				%end;
				put "		);";
			%end;
         %do i=1 %to &ntv;
         	put "   objRefNS:gbr&i = report(objRefNS:gb&i)[Graph Builder Box(1)];";
         	put "	  objRefNS:gbVars = objRefNS:gbr&i<<GetVariables();";
         	put "	  objRefNS:groupVarIndex = objRefNS:findVarByRole(objRefNS:gbVars,""Group Y"");";
         	put "	  if(objRefNS:groupVarIndex, objRefNS:gbr&i<<RemoveVariable(objRefNS:groupVarIndex));";
				put "   objRefNS:tbhlb&i << Delete;";
            put "   dbv2 = {};";
            put "   If(SVar == ""&trNone"",";
            	%if %upcase(&SplitResults)=YES %then %do;
         			put "		InsertInto(dbv2,eval(objrefns:dbv));";
            	%end;	
            	%if &doPercents or &doRates %then %do;
            		put "		InsertInto(dbv2,Column(""_GrpN_""));";
            	%end;
               put "    If(SVar2 != ""&trNone"",";   
               put "       InsertInto(dbv2,Column((objRefNS:glb2<<GetSelected)[1]));";
               put "    );";     
            put " ,";  /*else for grouping var */
            	put "	   objRefNS:gbr&i << AddVariable({Column(Svar),Role(""Group Y"")});";
            	put "    InsertInto(dbv2,Column((objRefNS:glb<<GetSelected)[1]));";
           		%if %upcase(&SplitResults)=YES %then %do;
         			put "		InsertInto(dbv2,eval(objrefns:dbv));";
            	%end;	            	
               %if &doPercents or &doRates %then %do;
               	put "		InsertInto(dbv2,Column(""_GrpN_""));";            	
               %end;
            	put "    If(Svar2 != ""&trNone"",";
               put "    	InsertInto(dbv2,Column((objRefNS:glb2<<GetSelected)[1]));";
            	put "    );";
            put "  );";   
            put "    objRefNS:tbvlb << Append( ";
                        %tabulate1(&i,%nrstr(eval(dbv2)),1);
            put "    );";
         %end;
         /* else if nothing selected, set to NONE */
         put "    ,";
         put "    objRefNS:glb << SetSelected(1,1);";
         put "    );";  /*end SelectOK condition */
         put " );";  /* End Column Switcher script */ 
         
         /* Script for stacking columns */
         /* kemicl - script for column switcher box */            
         put " objRefNS:glb2 << Set Script(";
         put "    SelectOK = 1;";
         put "    try((objRefNS:glb2<<GetSelected)[1],SelectOK = 0);";
         put "    If(SelectOK,";
         put "   objRefNS:DtExpr;";
         %do i=1 %to &ntv;
            put "   objRefNS:gbr&i = report(objRefNS:gb&i)[Graph Builder Box(1)];";
         	put "	  objRefNS:gbVars = objRefNS:gbr&i<<GetVariables();";
         	put "	  objRefNS:groupVarIndex = objRefNS:findVarByRole(objRefNS:gbVars,""Overlay"");";
         	put "	  if(objRefNS:groupVarIndex, objRefNS:gbr&i<<RemoveVariable(objRefNS:groupVarIndex));";
         	put "	  objRefNS:tbhlb&i << Delete;";
            put "   SVar2 = (objRefNS:glb2<<GetSelected)[1];";
            put "   SVar = (objRefNS:glb<<GetSelected)[1];";
            put "   dbv2 = {};";
            put "   If(SVar2 == ""&trNone"",";
            put "    If(SVar != ""&trNone"",";
               put "    InsertInto(dbv2,Column((objRefNS:glb<<GetSelected)[1]));";
            put "    );";
			%if %upcase(&SplitResults)=YES %then %do;
				put "		InsertInto(dbv2,eval(objrefns:dbv));";
			%end;           
            %if &doPercents or &doRates %then %do;
            	put "		InsertInto(dbv2,Column(""_GrpN_""));";
            %end;
            put "    objRefNS:tbvlb << Append( ";
                        %tabulate1(&i,%nrstr(eval(dbv2)),2);
            put "    );";        
            put " ,";  /* else for stacking var */
				put "	   objRefNS:gbr&i << AddVariable({Column(Svar2),Role(""Overlay"")});";
			%if %upcase(&SplitResults)=YES %then %do;
				put "		InsertInto(dbv2,eval(objrefns:dbv));";
			%end;				
            %if &doPercents or &doRates %then %do;
            	put "		InsertInto(dbv2,Column(""_GrpN_""));";				
            %end;
            put "    InsertInto(dbv2,Column((objRefNS:glb2<<GetSelected)[1]));";
            put "    If(SVar != ""&trNone"",";
               put "    InsertInto(dbv2,Column((objRefNS:glb<<GetSelected)[1]),1);";
            put "    );";
            put "    objRefNS:tbvlb << Append( ";
                        %tabulate1(&i,%nrstr(eval(dbv2)),3);
            put "    );";           
            put "  );";
         %end;
         /* else if nothing selected, set to NONE */
         put "    ,";
         put "    objRefNS:glb2 << SetSelected(1,1);";         
         put "    );";  /*end SelectOK condition */
         put " );";  /* End stacking Switcher script */           
         put ");";   /* End column switcher objRefNS:dd Function */  
      %end; 
   
      %if &ntv %then %do;
         put "InsertInto(objRefNS:TabButtonList, expr(locale:get(""CountsGraph_Text"")));";
         put "InsertInto(objRefNS:CreateReportList, {{objRefNS:TEAEText, objRefNS:gb1";
         %do i = 2 %to &ntv;
            put ",objRefNS:gb&i";
         %end;
         put "}});";
         put "InsertInto(objRefNS:CreateLiveReportList, {{objRefNS:TEAEText, objRefNS:gb1";
         %do i = 2 %to &ntv;
            put ",objRefNS:gb&i";
      %end;
         put "}});";      
      %end;
      %else %do;
         put "InsertInto(objRefNS:TabButtonList, expr(locale:get(""Distributions_Text"")));";
         put "InsertInto(objRefNS:CreateReportList, {{objRefNS:dd}});";
         put "InsertInto(objRefNS:CreateLiveReportList, {{objRefNS:dd}});";
      %end;
      put "InsertInto(objRefNS:DataList,{{""objRefNS:dmd""}});";
      put "InsertInto(objRefNS:DataNameList,{{locale:fill(locale:get(""XDistribution_Text""), {""%upcase(&domain)""})}});";
      put "InsertInto(objRefNS:TabCodeList,expr(objRefNS:ddw()));";
      %if (&ntv) %then %do;
         put "InsertInto(objRefNS:TabAfterCodeList, expr(objRefNS:ddwa()));";
         put "objRefNS:CloseTabOB = 1;";
      %end;
      %else %do;
         put "InsertInto(objRefNS:TabAfterCodeList, "" "");";     
      %end;
      put "InsertInto(objRefNS:TabOpenList,1);";
       
		put " objRefNS:tbfunc = Function({}, {default local},";
		put "    objRefNS:DtExpr;";
		put "	   VListBox(";
		%if &doRates %then %do;
			put "		objRefNS:tbtextbox = TextBox(""     "" || ""&trTextBoxTabulateRates"", <<Set Wrap(650),<<Set Font Size(9)),";
		%end;
		put "    objRefNS:tbvlb = Vlistbox(";
		%if %UPcase(&TrtUse) ne NONE and %length(&TrtLabel) %then %do;
			put "    objRefNS:tvcol = {Column(""&TrtLabel"")};";
			%if %upcase(&SplitResults)=YES %then %do;
				put "		InsertInto(objRefNS:tvcol,eval(objrefns:dbv));";
			%end;	
			%if &doPercents or &doRates  %then %do;
				put "    INsertInto(objRefNS:tvcol,Column(""_GrpN_""));";
			%end;			
			%if &NtrtPeriods > 1 %then %do;
				put "    InsertInto(objRefNS:tvcol,{Column(""Period"")});";
			%end;
			%do i=1 %to &ntv;
				%tabulate1(&i,%nrstr(eval(objRefNS:tvcol)),4); 
			%end;
		%end;
		%else %do;
			put "		objRefNS:tvcol = {};";
			%if %upcase(&SplitResults)=YES %then %do;
				put "		InsertInto(objRefNS:tvcol,eval(objrefns:dbv));";
			%end;	
			%if &doPercents or &doRates  %then %do;
				put "    INsertInto(objRefNS:tvcol,Column(""_GrpN_""));";
			%end;
			%do i=1 %to &ntv;
				%tabulate1(&i,%nrstr(eval(objRefNS:tvcol)),5); 
			%end;
		%end;
		put "    );";
		put " ));";

      %if &ntv  %then %do;
         put "InsertInto(objRefNS:TabButtonList, expr(locale:get(""CountsTable_Text"")));";
         put "InsertInto(objRefNS:CreateReportList, {{objRefNS:tbhlb1";
         %do i = 2 %to &ntv;
            put ",objRefNS:tbhlb&i";
         %end;
         put "}});";
         %let tabulateList = ;
         %do addTabNum=1 %to 5;
            %do i=1 %to &ntv;
               %if ^%length(&tabulateList) %then %let tabulateList = objRefNS:tb1_&addTabNum._&i;
               %else %let tabulateList = &tabulateList, objRefNS:tb1_&addTabNum._&i;
            %end;
         %end;
         put "InsertInto(objRefNS:CreateLiveReportList, {{&tabulateList}});";
         /*put "InsertInto(objRefNS:CreateLiveReportList, {{objRefNS:tbhlb1";
         %do i = 2 %to &ntv;
            put ",objRefNS:tbhlb&i";
         %end;
         put "}});";*/         
         put "InsertInto(objRefNS:DataList,{{""objRefNS:dmd""}});";
         put "InsertInto(objRefNS:DataNameList,{{locale:fill(locale:get(""XDistribution_Text""), {""%upcase(&domain)""})}});";
         put "InsertInto(objRefNS:TabCodeList,expr(objRefNS:tbfunc()));";
         put "InsertInto(objRefNS:TabAfterCodeList,"" "");";
         put "objRefNS:CloseTabOB = 1;";
         put "InsertInto(objRefNS:TabOpenList,1);";         

         put "objRefNS:ddwd=Function({},{default local},";
         put "objRefNS:DtExpr;";
         put "objRefNS:dbvd = {};";
         %do i=1 %to &ndbv;
            %if %quote(&&dbv&i) ne %quote(&TrtLabel) %then %do;
               put "InsertInto(objRefNS:dbvd,Column(""&&dbv&i""));";
            %end;
         %end;
         put " VListBox(";   
         put "      objRefNS:dd2 = objRefns:dmd<<Distribution(";
         put "               //Arrange in Rows(4),";
         put "            Automatic Recalc( 1 ),";
         %if %upcase(&SplitResults)=YES %then %do;
            put "         By(eval(objRefNS:dbvd)),";
         %end;

         put "         Nominal Distribution(Column(:Name(""&DecodLabel"")),ShowCounts(1), Order By( ""Count Ascending"" )),";
         %if %UPcase(&TrtUse) ne NONE and %length(&TrtLabel) %then %do;
            put "          Nominal Distribution(Column(:Name(""&TrtLabel"")), ShowCounts(1)),";
            %if &NtrtPeriods > 1 %then %do;
               put "          Nominal Distribution(Column(:Name(""Period"")), ShowCounts(1)),"; 
            %end;
         %end;
        %if &SLDOSEVar %then %do;
               put "         Continuous Distribution(Column(:Name(""&DoseLabel"")), ShowCounts(0), Quantiles(0),Summary Statistics(0)),";
         %end;             
         %if %length(&StdyLabel) %then %do;
            put "         Continuous Distribution(Column(:Name(""&StdyLabel"")), ShowCounts(0), Quantiles(0),Summary Statistics(0)),";
         %end;              
         %do i=1 %to &nev;
            put "         Nominal Distribution(Column(:Name(""&&evl&i"")), ShowCounts(1)";
            %if %length(&GroupVarLabel)  %then %do;
               %if "&&evl&i" = "&GroupVarLabel" %then %do;
                  put "       ,Order By( ""Count Ascending"" )";
               %end;
            %end;
            put "),";
         %end; 
         put "         SendToReport(";
         %if %UPcase(&TrtUse) ne NONE and %length(&TrtLabel) %then %do;
            put "            Dispatch( {""&TrtLabel""}, ""Frequencies"", OutlineBox, Close( 1 ) ),";
         %end;
         put " //          Dispatch( {""&StdyLabel""}, ""Quantiles"", OutlineBox, Close( 1 ) ),";
         put " //          Dispatch( {""&StdyLabel""}, ""Summary Statistics"", OutlineBox, Close( 1 ) ),";  
         put "            Dispatch( {""&DecodLabel""}, ""Frequencies"", OutlineBox, Close( 1 ) ),";
         %do i=1 %to &nev;
               put "            Dispatch( {""&&evl&i""}, ""Frequencies"", OutlineBox, Close( 1 ) ),";
         %end;

         put "         )";
         put "      ))";
         put " );";
         put "InsertInto(objRefNS:DataList,{{""objRefNS:dmd""}});";
         put "InsertInto(objRefNS:DataNameList,{{locale:fill(locale:get(""XDistribution_Text""), {""%upcase(&domain)""})}});";
         put "InsertInto(objRefNS:TabButtonList, expr(locale:get(""Distributions_Text"") || "" ""));";
         put "InsertInto(objRefNS:TabCodeList,expr(objRefNS:ddwd()));";
         put "InsertInto(objRefNS:TabAfterCodeList, "" "");";
         put "InsertInto(objRefNS:TabOpenList,1);";
         put "InsertInto(objRefNS:CreateReportList,{{objRefNS:dd2}});";
         put "InsertInto(objRefNS:CreateLiveReportList,{{objRefNS:dd2}});";
      %end;

      %SubjectDrillDowns;

		put "InsertInto(objRefNS:ActionButtonDesc , {Expr(locale:get(""ClicktoView_Text""))});";;
		put "Include(""$CLINICAL_HOME\JSLFiles\Distribution Drill Down Functions.jsl"");";   

		%if &doSite %then %do;
			put "InsertInto(objRefNS:ActionButtonList[1], {expr(locale:get(""DemographicCounts_Text""))});";
			put "InsertInto(objRefNS:ActionCodeList[1],Expr(objRefNS:SSfctn(""&SiteLabel"",""&TrtLabel"", ""&AxLab"")));";
			put "InsertInto(objRefNS:ActionIconList[1],""&IconPath.DemographicCounts.gif"");";
			put "InsertInto(objRefNS:ActionSelectionCountList[1],1);";           
			put "InsertInto(objRefNS:ActionRequirementFlagList[1],0);";
		%end;    
		/*
		%if %upcase(&domain) = CM or %upcase(&domain) = AE %then %do;
			%if %sysfunc(findw(&domains, %upcase(&crossdomain))) > 0 %then %do;
				put "InsertInto(objRefNS:ActionButtonList[2], {expr(locale:fill(locale:get(""RelatedX_Text""),{""%upcase(&crossdomain)""}))});";
				put "InsertInto(objRefNS:ActionCodeList[2],Expr(objRefNS:AECMfctn(""&crossdomain"",""&APddname"",locale:fill(locale:get(""RelatedX_Text""),{""%upcase(&crossdomain)""}))));";
				%if %upcase(&crossdomain) = AE %then %let RXIcon = %nrbquote(&IconPath.RelatedAE.gif);
				%else %if %upcase(&crossdomain) = CM %then %let RXIcon = %nrbquote(&IconPath.RelatedConcomitantMedications.gif);
				%else %if %upcase(&crossdomain) = EG %then %let RXIcon = %nrbquote(&IconPath.RelatedECG.gif);
				%else %if %upcase(&crossdomain) = LB %then %let RXIcon = %nrbquote(&IconPath.Labs.gif);
				%else %if %upcase(&crossdomain) = VS %then %let RXIcon = %nrbquote(&IconPath.RelatedVitals.gif);
				%else %let RXIcon = %nrbquote(&IconPath.DonutGraph3d.gif);
				put "InsertInto(objRefNS:ActionIconList[2],""&RXIcon"");";
				put "InsertInto(objRefNS:ActionSelectionCountList[2],1);";
				put "InsertInto(objRefNS:ActionRequirementFlagList[2],3);";
			%end;
		%end;                
		%if %sysfunc(findw(&domains, LB)) %then %do;
			put "InsertInto(objRefNS:ActionButtonList[2], {expr(locale:get(""RelatedLabs_Text""))});";
			put "InsertInto(objRefNS:ActionCodeList[2],Expr(objRefNS:AECMfctn(""LB"",""FindingsTimeTrends"",locale:get(""RelatedLabs_Text""))));";
			put "InsertInto(objRefNS:ActionIconList[2],""&IconPath.Labs.gif"");";
			put "InsertInto(objRefNS:ActionSelectionCountList[2],1);";           
			put "InsertInto(objRefNS:ActionRequirementFlagList[2],3);";
		%end;
		%if %sysfunc(findw(&domains, VS))>0 %then %do;
			put "InsertInto(objRefNS:ActionButtonList[2], {expr(locale:get(""RelatedVitals_Text""))});";
			put "InsertInto(objRefNS:ActionCodeList[2],Expr(objRefNS:AECMfctn(""VS"",""FindingsTimeTrends"",locale:get(""RelatedVitals_Text""))));";
			put "InsertInto(objRefNS:ActionIconList[2],""&IconPath.RelatedVitals.gif"");";
			put "InsertInto(objRefNS:ActionSelectionCountList[2],1);";           
			put "InsertInto(objRefNS:ActionRequirementFlagList[2],3);";
		%end;
		%if %sysfunc(findw(&domains, EG))>0 %then %do;
			put "InsertInto(objRefNS:ActionButtonList[2], {expr(locale:get(""RelatedECG_Text""))});";
			put "InsertInto(objRefNS:ActionCodeList[2],Expr(objRefNS:AECMfctn(""EG"",""FindingsTimeTrends"",locale:get(""RelatedECG_Text""))));"; 
			put "InsertInto(objRefNS:ActionIconList[2],""&IconPath.RelatedECG.gif"");";
			put "InsertInto(objRefNS:ActionSelectionCountList[2],1);";           
			put "InsertInto(objRefNS:ActionRequirementFlagList[2],3);";
		%end; 
		*/
		%if %upcase(&domain) = AE %then %do;
			put "objRefNS:ActionButtonList[2]={};";
			put "objRefNS:ActionCodeList[2] ={};";
			put "objRefNS:ActionIconList[2] = {};";
			put "objRefNS:ActionSelectionCountList[2] = {};";
			put "objRefNS:ActionRequirementFlagList[2] = {};";		
			put "objRefNS:ActionButtonList[2]={expr(locale:get(""UniqueOccurrenceSubjectCounts_Text""))};";
			put "objRefNS:ActionCodeList[2] ={expr(objRefNS:AECountsfctn(""&SubjectLabel"", ""&DecodLabel""))};";
			put "objRefNS:ActionIconList[2] = {""&IconPath.SingleOccuranceSubjectCountReport.gif""};";
			put "objRefNS:ActionSelectionCountList[2] = {0};";
			put "objRefNS:ActionRequirementFlagList[2] = {0};";
			put "objRefNS:ShowLiveReviewFilter = 0;";
		%end;

      
      
   run;

   %PackageInsertFile(jsl code from &ProcessName, &OutPath, &DistributionScriptName, &Distribution_OutDataName..sas7bdat, text/plain); 

   %mexit:;

%mend;

